@@ -62,6 +62,9 @@ typedef struct {
 									 BraseroBurnError error,
 									 BraseroMedia required_media);
 
+	BraseroBurnResult		(*eject_failure)				(BraseroBurn *obj,
+							                                  BraseroDrive *drive);
+
 	BraseroBurnResult		(*location_request)		(BraseroBurn *obj,
 									 GError *error,
 									 gboolean is_temporary);
@@ -83,8 +86,8 @@ typedef struct {
 									 BraseroBurnAction action);
 } BraseroBurnClass;
 
-GType brasero_burn_get_type ();
-BraseroBurn *brasero_burn_new ();
+GType brasero_burn_get_type (void);
+BraseroBurn *brasero_burn_new (void);
 
 BraseroBurnResult 
 brasero_burn_record (BraseroBurn *burn,
@@ -117,6 +120,4 @@ brasero_burn_get_action_string (BraseroBurn *burn,
 				BraseroBurnAction action,
 				gchar **string);
 
-G_END_DECLS
-
 #endif /* BURN_H */
