@@ -46,6 +46,7 @@ G_BEGIN_DECLS
 GSList *
 brasero_burn_caps_new_task (BraseroBurnCaps *caps,
 			    BraseroBurnSession *session,
+                            BraseroTrackType *temp_output,
 			    GError **error);
 BraseroTask *
 brasero_burn_caps_new_blanking_task (BraseroBurnCaps *caps,
@@ -57,6 +58,4 @@ brasero_burn_caps_new_checksuming_task (BraseroBurnCaps *caps,
 					GError **error);
 
 
-G_END_DECLS
-
 #endif /* _BRASERO_CAPS_BURN_H_ */
