@@ -173,9 +173,9 @@ brasero_src_image_update (BraseroSrcImage *self)
 {
 	gchar *uri;
 	gchar *name;
-	GFile *file;
 	gchar *string;
 	goffset bytes = 0;
+	GFile *file = NULL;
 	GError *error = NULL;
 	BraseroStatus *status;
 	BraseroBurnResult result;
@@ -214,9 +214,11 @@ brasero_src_image_update (BraseroSrcImage *self)
 	g_free (uri);
 
 	name = g_file_get_basename (file);
-	g_object_unref (file);
-	if (!name)
+	if (!name) {
+		if (file)
+			g_object_unref (file);
 		return;
+	}
 
 	/* See if information retrieval went fine and/or is ready */
 	status = brasero_status_new ();
@@ -243,7 +245,8 @@ brasero_src_image_update (BraseroSrcImage *self)
 		goto end;
 	}
 
-	gtk_widget_set_tooltip_text (GTK_WIDGET (self), NULL);
+	uri = g_file_get_uri (file);
+	gtk_widget_set_tooltip_text (GTK_WIDGET (self), uri);
 
 	/* Deal with size */
 	brasero_track_get_size (BRASERO_TRACK (priv->track), NULL, &bytes);
@@ -257,7 +260,10 @@ brasero_src_image_update (BraseroSrcImage *self)
 
 end:
 
-	brasero_status_free (status);
+	if (file)
+		g_object_unref (file);
+
+	g_object_unref (status);
 	if (string) {
 		/* This is hackish and meant to avoid ellipsization to make the
 		 * label to small. */
@@ -443,7 +449,6 @@ brasero_src_image_clicked (GtkButton *button)
 	gtk_file_filter_add_mime_type (filter, mimes [1]);
 	gtk_file_filter_add_mime_type (filter, mimes [2]);
 	gtk_file_filter_add_mime_type (filter, mimes [3]);
-	gtk_file_filter_add_mime_type (filter, "image/*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (priv->file), filter);
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (priv->file), filter);
 
