@@ -54,6 +54,13 @@ struct _BraseroTrackDataPrivate
 
 G_DEFINE_TYPE (BraseroTrackData, brasero_track_data, BRASERO_TYPE_TRACK);
 
+/**
+ * brasero_graft_point_free:
+ * @graft: a #BraseroGraftPt
+ *
+ * Frees @graft. Do not use @grafts afterwards.
+ *
+ **/
 
 void
 brasero_graft_point_free (BraseroGraftPt *graft)
@@ -65,6 +72,15 @@ brasero_graft_point_free (BraseroGraftPt *graft)
 	g_free (graft);
 }
 
+/**
+ * brasero_graft_point_copy:
+ * @graft: a #BraseroGraftPt
+ *
+ * Copies @graft.
+ *
+ * Return value: a #BraseroGraftPt.
+ **/
+
 BraseroGraftPt *
 brasero_graft_point_copy (BraseroGraftPt *graft)
 {
@@ -80,7 +96,7 @@ brasero_graft_point_copy (BraseroGraftPt *graft)
 	return newgraft;
 }
 
-BraseroBurnResult
+static BraseroBurnResult
 brasero_track_data_set_source_real (BraseroTrackData *track,
 				    GSList *grafts,
 				    GSList *unreadable)
@@ -108,6 +124,23 @@ brasero_track_data_set_source_real (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_set_source:
+ * @track: a #BraseroTrackData.
+ * @grafts: (element-type BraseroBurn.GraftPt) (in) (transfer full): a #GSList of #BraseroGraftPt.
+ * @unreadable: (element-type utf8) (allow-none) (in) (transfer full): a #GSList of URIS as strings or %NULL.
+ *
+ * Sets the lists of grafts points (@grafts) and excluded
+ * URIs (@unreadable) to be used to create an image.
+ *
+ * Be careful @track takes ownership of @grafts and
+ * @unreadable which must not be freed afterwards.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_set_source (BraseroTrackData *track,
 			       GSList *grafts,
@@ -132,6 +165,19 @@ brasero_track_data_add_fs_real (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_add_fs:
+ * @track: a #BraseroTrackData
+ * @fstype: a #BraseroImageFS
+ *
+ * Adds one or more parameters determining the file system type
+ * and various other options to create an image.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_add_fs (BraseroTrackData *track,
 			   BraseroImageFS fstype)
@@ -168,6 +214,19 @@ brasero_track_data_rm_fs_real (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_rm_fs:
+ * @track: a #BraseroTrackData
+ * @fstype: a #BraseroImageFS
+ *
+ * Removes one or more parameters determining the file system type
+ * and various other options to create an image.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_rm_fs (BraseroTrackData *track,
 			  BraseroImageFS fstype)
@@ -193,6 +252,18 @@ brasero_track_data_rm_fs (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_set_data_blocks:
+ * @track: a #BraseroTrackData
+ * @blocks: a #goffset
+ *
+ * Sets the size of the image to be created (in sectors of 2048 bytes).
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_set_data_blocks (BraseroTrackData *track,
 				    goffset blocks)
@@ -207,6 +278,18 @@ brasero_track_data_set_data_blocks (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_set_file_num:
+ * @track: a #BraseroTrackData
+ * @number: a #guint64
+ *
+ * Sets the number of files (not directories) in @track.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful,
+ * BRASERO_BURN_ERR otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_set_file_num (BraseroTrackData *track,
 				 guint64 number)
@@ -221,6 +304,16 @@ brasero_track_data_set_file_num (BraseroTrackData *track,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * brasero_track_data_get_fs:
+ * @track: a #BraseroTrackData
+ *
+ * Returns the parameters determining the file system type
+ * and various other options to create an image.
+ *
+ * Return value: a #BraseroImageFS.
+ **/
+
 BraseroImageFS
 brasero_track_data_get_fs (BraseroTrackData *track)
 {
@@ -232,7 +325,7 @@ brasero_track_data_get_fs (BraseroTrackData *track)
 	return klass->get_fs (track);
 }
 
-BraseroImageFS
+static BraseroImageFS
 brasero_track_data_get_fs_real (BraseroTrackData *track)
 {
 	BraseroTrackDataPrivate *priv;
@@ -241,6 +334,17 @@ brasero_track_data_get_fs_real (BraseroTrackData *track)
 	return priv->fs_type;
 }
 
+/**
+ * brasero_track_data_get_grafts:
+ * @track: a #BraseroTrackData
+ *
+ * Returns a list of #BraseroGraftPt.
+ *
+ * Do not free after usage as @track retains ownership.
+ *
+ * Return value: (transfer none) (element-type BraseroBurn.GraftPt) (allow-none): a #GSList of #BraseroGraftPt or %NULL if empty.
+ **/
+
 GSList *
 brasero_track_data_get_grafts (BraseroTrackData *track)
 {
@@ -261,7 +365,48 @@ brasero_track_data_get_grafts_real (BraseroTrackData *track)
 	return priv->grafts;
 }
 
+/**
+ * brasero_track_data_get_excluded_list:
+ * @track: a #BraseroTrackData.
+ *
+ * Returns a list of URIs which must not be included in
+ * the image to be created.
+ * Do not free the list or any of the URIs after
+ * usage as @track retains ownership.
+ *
+ * Return value: (transfer none) (element-type utf8) (allow-none): a #GSList of #gchar * or %NULL if no
+ * URI should be excluded.
+ **/
+
 GSList *
+brasero_track_data_get_excluded_list (BraseroTrackData *track)
+{
+	BraseroTrackDataClass *klass;
+
+	g_return_val_if_fail (BRASERO_IS_TRACK_DATA (track), NULL);
+
+	klass = BRASERO_TRACK_DATA_GET_CLASS (track);
+	return klass->get_excluded (track);
+}
+
+/**
+ * brasero_track_data_get_excluded:
+ * @track: a #BraseroTrackData.
+ * @copy: a #gboolean.
+ *
+ * Returns a list of URIs which must not be included in
+ * the image to be created.
+ * If @copy is %TRUE then the @list is a copy and must
+ * be freed once it is not needed anymore. If %FALSE,
+ * do not free after usage as @track retains ownership.
+ *
+ * Deprecated since 2.29.2
+ *
+ * Return value: a #GSList of #gchar * or %NULL if no
+ * URI should be excluded.
+ **/
+
+G_GNUC_DEPRECATED GSList *
 brasero_track_data_get_excluded (BraseroTrackData *track,
 				 gboolean copy)
 {
@@ -296,7 +441,33 @@ brasero_track_data_get_excluded_real (BraseroTrackData *track)
 	return priv->excluded;
 }
 
-BraseroBurnResult
+/**
+ * brasero_track_data_get_paths:
+ * @track: a #BraseroTrackData.
+ * @use_joliet: a #gboolean.
+ * @grafts_path: a #gchar.
+ * @excluded_path: a #gchar.
+ * @emptydir: a #gchar.
+ * @videodir: (allow-none): a #gchar or %NULL.
+ * @error: a #GError.
+ *
+ * Write in @grafts_path (a path to a file) the graft points,
+ * in @excluded_path (a path to a file) the list of paths to
+ * be excluded, @emptydir (a path to a file) an empty
+ * directory to be used for created directories, @videodir
+ * (a path to a file) for a directory to be used to build the
+ * the video image.
+ *
+ * This is mostly for internal use by mkisofs and similar.
+ *
+ * This function takes care of mangling.
+ *
+ * Deprecated since 2.29.2
+ *
+ * Return value: a #BraseroBurnResult.
+ **/
+
+G_GNUC_DEPRECATED BraseroBurnResult
 brasero_track_data_get_paths (BraseroTrackData *track,
 			      gboolean use_joliet,
 			      const gchar *grafts_path,
@@ -327,6 +498,70 @@ brasero_track_data_get_paths (BraseroTrackData *track,
 	return result;
 }
 
+/**
+ * brasero_track_data_write_to_paths:
+ * @track: a #BraseroTrackData.
+ * @grafts_path: a #gchar.
+ * @excluded_path: a #gchar.
+ * @emptydir: a #gchar.
+ * @videodir: (allow-none): a #gchar or %NULL.
+ * @error: a #GError.
+ *
+ * Write to @grafts_path (a path to a file) the graft points,
+ * and to @excluded_path (a path to a file) the list of paths to
+ * be excluded; @emptydir is (path) is an empty
+ * directory to be used for created directories;
+ * @videodir (a path) is a directory to be used to build the
+ * the video image.
+ *
+ * This is mostly for internal use by mkisofs and similar.
+ *
+ * This function takes care of file name mangling.
+ *
+ * Return value: a #BraseroBurnResult.
+ **/
+
+BraseroBurnResult
+brasero_track_data_write_to_paths (BraseroTrackData *track,
+                                   const gchar *grafts_path,
+                                   const gchar *excluded_path,
+                                   const gchar *emptydir,
+                                   const gchar *videodir,
+                                   GError **error)
+{
+	GSList *grafts;
+	GSList *excluded;
+	BraseroBurnResult result;
+	BraseroTrackDataClass *klass;
+
+	g_return_val_if_fail (BRASERO_IS_TRACK_DATA (track), BRASERO_BURN_NOT_SUPPORTED);
+
+	klass = BRASERO_TRACK_DATA_GET_CLASS (track);
+	grafts = klass->get_grafts (track);
+	excluded = klass->get_excluded (track);
+
+	result = brasero_mkisofs_base_write_to_files (grafts,
+						      excluded,
+						      brasero_track_data_get_fs (track),
+						      emptydir,
+						      videodir,
+						      grafts_path,
+						      excluded_path,
+						      error);
+	return result;
+}
+
+/**
+ * brasero_track_data_get_file_num:
+ * @track: a #BraseroTrackData.
+ * @file_num: (allow-none) (out): a #guint64 or %NULL.
+ *
+ * Sets the number of files (not directories) in @file_num.
+ *
+ * Return value: a #BraseroBurnResult. %TRUE if @file_num
+ * was set, %FALSE otherwise.
+ **/
+
 BraseroBurnResult
 brasero_track_data_get_file_num (BraseroTrackData *track,
 				 guint64 *file_num)
@@ -399,7 +634,7 @@ brasero_track_data_get_status (BraseroTrack *track,
 			brasero_status_set_error (status,
 						  g_error_new (BRASERO_BURN_ERROR,
 							       BRASERO_BURN_ERROR_EMPTY,
-							       _("The project is empty")));
+							       _("There are no files to write to disc")));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -413,6 +648,21 @@ brasero_track_data_init (BraseroTrackData *object)
 static void
 brasero_track_data_finalize (GObject *object)
 {
+	BraseroTrackDataPrivate *priv;
+
+	priv = BRASERO_TRACK_DATA_PRIVATE (object);
+	if (priv->grafts) {
+		g_slist_foreach (priv->grafts, (GFunc) brasero_graft_point_free, NULL);
+		g_slist_free (priv->grafts);
+		priv->grafts = NULL;
+	}
+
+	if (priv->excluded) {
+		g_slist_foreach (priv->excluded, (GFunc) g_free, NULL);
+		g_slist_free (priv->excluded);
+		priv->excluded = NULL;
+	}
+
 	G_OBJECT_CLASS (brasero_track_data_parent_class)->finalize (object);
 }
 
@@ -441,6 +691,17 @@ brasero_track_data_class_init (BraseroTrackDataClass *klass)
 	track_data_class->get_file_num = brasero_track_data_get_file_num_real;
 }
 
+/**
+ * brasero_track_data_new:
+ *
+ * Creates a new #BraseroTrackData.
+ * 
+ *This type of tracks is used to create a disc image
+ * from or burn a selection of files.
+ *
+ * Return value: a #BraseroTrackData
+ **/
+
 BraseroTrackData *
 brasero_track_data_new (void)
 {
