@@ -33,6 +33,7 @@
 #endif
 
 #include <string.h>
+#include <stdio.h>
 
 #include <glib.h>
 #include <glib/gi18n-lib.h>
@@ -44,6 +45,8 @@
 #include "brasero-track.h"
 #include "brasero-media.h"
 
+#include "brasero-burn-lib.h"
+
 static gboolean debug = FALSE;
 
 static const GOptionEntry options [] = {
@@ -53,6 +56,12 @@ static const GOptionEntry options [] = {
 	{ NULL }
 };
 
+void
+brasero_burn_library_set_debug (gboolean value)
+{
+	debug = value;
+}
+
 /**
  * brasero_burn_library_get_option_group:
  *
@@ -94,15 +103,12 @@ brasero_burn_debug_message (const gchar *location,
 	if (!debug)
 		return;
 
-	format_real = g_strdup_printf ("At %s: %s",
+	format_real = g_strdup_printf ("BraseroBurn: (at %s) %s\n",
 				       location,
 				       format);
 
 	va_start (arg_list, format);
-	g_logv (BRASERO_BURN_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
+	vprintf (format_real, arg_list);
 	va_end (arg_list);
 
 	g_free (format_real);
@@ -118,15 +124,11 @@ brasero_burn_debug_messagev (const gchar *location,
 	if (!debug)
 		return;
 
-	format_real = g_strdup_printf ("At %s: %s",
+	format_real = g_strdup_printf ("BraseroBurn: (at %s) %s\n",
 				       location,
 				       format);
 
-	g_logv (BRASERO_BURN_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
-
+	vprintf (format_real, arg_list);
 	g_free (format_real);
 }
 
@@ -179,16 +181,13 @@ brasero_burn_debug_flags_type_message (BraseroBurnFlag flags,
 
 	brasero_debug_burn_flags_to_string (buffer, flags);
 
-	format_real = g_strdup_printf ("At %s: %s %s",
+	format_real = g_strdup_printf ("BraseroBurn: (at %s) %s %s\n",
 				       location,
 				       format,
 				       buffer);
 
 	va_start (arg_list, format);
-	g_logv (BRASERO_BURN_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
+	vprintf (format_real, arg_list);
 	va_end (arg_list);
 
 	g_free (format_real);
@@ -238,8 +237,8 @@ brasero_debug_audio_format_to_string (gchar *buffer,
 	if (format & BRASERO_AUDIO_FORMAT_UNDEFINED)
 		strcat (buffer, "AUDIO UNDEFINED ");
 
-	if (format & BRASERO_AUDIO_FORMAT_4_CHANNEL)
-		strcat (buffer, "4 CHANNELS ");
+	if (format & BRASERO_AUDIO_FORMAT_DTS)
+		strcat (buffer, "DTS WAV ");
 
 	if (format & BRASERO_AUDIO_FORMAT_MP2)
 		strcat (buffer, "MP2 ");
@@ -317,16 +316,13 @@ brasero_burn_debug_track_type_struct_message (BraseroTrackType *type,
 	else
 		strcpy (buffer, "Undefined");
 
-	format_real = g_strdup_printf ("At %s: %s %s",
+	format_real = g_strdup_printf ("BraseroBurn: (at %s) %s %s\n",
 				       location,
 				       format,
 				       buffer);
 
 	va_start (arg_list, format);
-	g_logv (BRASERO_BURN_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
+	vprintf (format_real, arg_list);
 	va_end (arg_list);
 
 	g_free (format_real);
@@ -387,16 +383,13 @@ brasero_burn_debug_track_type_message (BraseroTrackDataType type,
 		break;
 	}
 
-	format_real = g_strdup_printf ("At %s: %s %s",
+	format_real = g_strdup_printf ("BraseroBurn: (at %s) %s %s\n",
 				       location,
 				       format,
 				       buffer);
 
 	va_start (arg_list, format);
-	g_logv (BRASERO_BURN_LOG_DOMAIN,
-		G_LOG_LEVEL_DEBUG,
-		format_real,
-		arg_list);
+	vprintf (format_real, arg_list);
 	va_end (arg_list);
 
 	g_free (format_real);
