@@ -62,7 +62,7 @@
 
 
 const gchar *types [] = {	N_("File"),
-				N_("CDROM"),
+				N_("CD-ROM"),
 				N_("CD-R"),
 				N_("CD-RW"),
 				N_("DVD-ROM"),
@@ -2342,7 +2342,7 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 						 &size,
 						 NULL);
 		if (result != BRASERO_SCSI_OK) {
-			/* CDROM */
+			/* CD-ROM */
 			priv->info = BRASERO_MEDIUM_CDROM;
 			priv->type = types [1];
 		}
@@ -3251,14 +3251,6 @@ brasero_medium_class_init (BraseroMediumClass *klass)
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
-
-/* This function is not public API yet because it was too
- * late; so use it internally for now. It's mainly for 
- * convenience.*/
-gboolean
-brasero_drive_can_write_media (BraseroDrive *drive,
-                               BraseroMedia media);
-
 /**
  * brasero_medium_can_be_written:
  * @medium: #BraseroMedium
@@ -3325,6 +3317,8 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
  *
  * Gets whether the medium supports SAO.
  *
+ * Since 2.29
+ *
  * Return value: a #gboolean. TRUE if the medium can use SAO write mode , FALSE otherwise.
  *
  **/
@@ -3345,6 +3339,8 @@ brasero_medium_can_use_sao (BraseroMedium *medium)
  *
  * Gets whether the medium supports TAO.
  *
+ * Since 2.29
+ *
  * Return value: a #gboolean. TRUE if the medium can use TAO write mode, FALSE otherwise.
  *
  **/
@@ -3425,7 +3421,7 @@ brasero_medium_can_use_burnfree (BraseroMedium *medium)
  *
  * Gets the #BraseroDrive in which the medium is inserted.
  *
- * Return value: a #BraseroDrive. No need to unref after use.
+ * Return value: (transfer none): a #BraseroDrive. No need to unref after use.
  *
  **/
 BraseroDrive *
