@@ -85,6 +85,9 @@ struct BraseroMetadataPrivate {
 
 	gint listeners;
 
+	BraseroMetadataGetXidCb xid_callback;
+	gpointer xid_user_data;
+
 	guint started:1;
 	guint moved_forward:1;
 	guint prev_level_mes:1;
@@ -116,6 +119,30 @@ G_DEFINE_TYPE (BraseroMetadata, brasero_metadata, G_TYPE_OBJECT)
 static GSList *downloading = NULL;
 static GSList *downloaded = NULL;
 
+static int
+brasero_metadata_get_xid (BraseroMetadata *metadata)
+{
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (metadata);
+	if (!priv->xid_callback)
+		return 0;
+
+	return priv->xid_callback (priv->xid_user_data);
+}
+
+void
+brasero_metadata_set_get_xid_callback (BraseroMetadata *metadata,
+                                       BraseroMetadataGetXidCb callback,
+                                       gpointer user_data)
+{
+	BraseroMetadataPrivate *priv;
+
+	priv = BRASERO_METADATA_PRIVATE (metadata);
+	priv->xid_callback = callback;
+	priv->xid_user_data = user_data;
+}
+
 struct _BraseroMetadataGstDownload {
 	gchar *detail;
 
@@ -961,9 +988,11 @@ brasero_metadata_install_plugins_success (BraseroMetadataGstDownload *download)
 
 		priv = BRASERO_METADATA_PRIVATE (iter->data);
 
-		/* free previously saved error message */
-		g_error_free (priv->error);
-		priv->error = NULL;
+		if (priv->error) {
+			/* free previously saved error message */
+			g_error_free (priv->error);
+			priv->error = NULL;
+		}
 
 		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_NULL);
 		gst_element_set_state (GST_ELEMENT (priv->pipeline), GST_STATE_PLAYING);
@@ -974,14 +1003,20 @@ static void
 brasero_metadata_install_plugins_abort (BraseroMetadataGstDownload *download)
 {
 	GSList *iter;
+	GSList *next;
 
-	for (iter = download->objects; iter; iter = iter->next) {
+	for (iter = download->objects; iter; iter = next) {
 		BraseroMetadataPrivate *priv;
 
+		next = iter->next;
+
 		priv = BRASERO_METADATA_PRIVATE (iter->data);
 
-		g_error_free (priv->error);
-		priv->error = NULL;
+		if (priv->error) {
+			g_error_free (priv->error);
+			priv->error = NULL;
+		}
+
 		brasero_metadata_completed (BRASERO_METADATA (iter->data));
 	}
 }
@@ -1066,6 +1101,7 @@ brasero_metadata_is_downloading (const gchar *detail)
 		if (!strcmp (download->detail, detail))
 			return download;
 	}
+
 	return NULL;
 }
 
@@ -1093,6 +1129,7 @@ brasero_metadata_install_missing_plugins (BraseroMetadata *self)
 		 * - is being downloaded
 		 * If so don't do anything. */
 		detail = gst_missing_plugin_message_get_installer_detail (iter->data);
+
 		download = brasero_metadata_is_downloading (detail);
 		if (download) {
 			download->objects = g_slist_prepend (download->objects, self);
@@ -1130,6 +1167,7 @@ brasero_metadata_install_missing_plugins (BraseroMetadata *self)
 	/* FIXME: we'd need the main window here to set it modal */
 
 	context = gst_install_plugins_context_new ();
+	gst_install_plugins_context_set_xid (context, brasero_metadata_get_xid (self));
 	status = gst_install_plugins_async ((gchar **) details->pdata,
 					    context,
 					    brasero_metadata_install_plugins_result,
@@ -1181,10 +1219,10 @@ brasero_metadata_bus_messages (GstBus *bus,
 
 		/* here we just want to check if that's a missing codec */
 		if ((priv->flags & BRASERO_METADATA_FLAG_MISSING)
-		     &&   gst_is_missing_plugin_message (msg))
+		&&   gst_is_missing_plugin_message (msg))
 			priv->missing_plugins = g_slist_prepend (priv->missing_plugins, gst_message_ref (msg));
 		else if (!strcmp (gst_structure_get_name (msg->structure), "level")
-		     &&   gst_structure_has_field (msg->structure, "peak")) {
+		&&   gst_structure_has_field (msg->structure, "peak")) {
 			const GValue *value;
 			const GValue *list;
 			gdouble peak;
@@ -1305,6 +1343,23 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 		 * around after the bin they've been added to is destroyed
 		 * NOTE: now we destroy the pipeline every time which means
 		 * that it doesn't really matter. */
+		if (!priv->level) {
+			priv->level = gst_element_factory_make ("level", NULL);
+			if (!priv->level) {
+				priv->error = g_error_new (BRASERO_UTILS_ERROR,
+							   BRASERO_UTILS_ERROR_GENERAL,
+							   _("%s element could not be created"),
+							   "\"Level\"");
+				gst_object_unref (priv->audio);
+				priv->audio = NULL;
+				return FALSE;
+			}
+			g_object_set (priv->level,
+				      "message", TRUE,
+				      "interval", (guint64) BRASERO_METADATA_SILENCE_INTERVAL,
+				      NULL);
+		}
+
 		gst_object_ref (priv->convert);
 		gst_object_ref (priv->level);
 		gst_object_ref (priv->sink);
@@ -1314,6 +1369,7 @@ brasero_metadata_create_audio_pipeline (BraseroMetadata *self)
 				  priv->level,
 				  priv->sink,
 				  NULL);
+
 		if (!gst_element_link_many (priv->convert,
 		                            priv->level,
 		                            priv->sink,
@@ -1682,19 +1738,6 @@ brasero_metadata_create_pipeline (BraseroMetadata *self)
 		return FALSE;
 	}
 
-	priv->level = gst_element_factory_make ("level", NULL);
-	if (!priv->level) {
-		priv->error = g_error_new (BRASERO_UTILS_ERROR,
-					   BRASERO_UTILS_ERROR_GENERAL,
-					   _("%s element could not be created"),
-					   "\"Level\"");
-		return FALSE;
-	}
-	g_object_set (priv->level,
-		      "message", TRUE,
-		      "interval", (guint64) BRASERO_METADATA_SILENCE_INTERVAL,
-		      NULL);
-
 	priv->sink = gst_element_factory_make ("fakesink", NULL);
 	if (priv->sink == NULL) {
 		priv->error = g_error_new (BRASERO_UTILS_ERROR,
@@ -1804,8 +1847,11 @@ brasero_metadata_set_uri (BraseroMetadata *self,
 
 	priv->flags = flags;
 	if (!brasero_metadata_set_new_uri (self, uri)) {
-		g_propagate_error (error, priv->error);
-		priv->error = NULL;
+		if (priv->error) {
+			BRASERO_UTILS_LOG ("Failed to set new URI %s", priv->error->message);
+			g_propagate_error (error, priv->error);
+			priv->error = NULL;
+		}
 
 		brasero_metadata_info_free (priv->info);
 		priv->info = NULL;
@@ -1847,6 +1893,7 @@ brasero_metadata_get_info_async (BraseroMetadata *self,
 		g_object_unref (self);
 
 		if (priv->error) {
+			BRASERO_UTILS_LOG ("Failed to set new URI %s", priv->error->message);
 			g_error_free (priv->error);
 			priv->error = NULL;
 		}
