@@ -29,6 +29,9 @@
 #include <glib/gi18n-lib.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+
+#include <gconf/gconf-client.h>
+
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-extension/nautilus-location-widget-provider.h>
 
@@ -58,6 +61,9 @@
 
 #include "brasero-misc.h"
 
+#include "brasero-media-private.h"
+#include "burn-debug.h"
+
 #define BURN_URI "burn:///"
 
 #define NAUTILUS_TYPE_DISC_BURN  (nautilus_disc_burn_get_type ())
@@ -101,16 +107,27 @@ static GObjectClass *parent_class;
 
 static void
 launch_brasero_on_window_session (BraseroSessionCfg	*session,
+                                  const gchar		*dialog_title,
 				  GtkWidget		*options,
 				  GtkWindow		*window)
 {
+	const gchar			*icon_name;
 	GtkWidget		*dialog;
 	GtkResponseType		 result;
 
+	/* Get the icon for the window */
+	if (window)
+		icon_name = gtk_window_get_icon_name (window);
+	else
+		icon_name = "brasero";
+
 	/* run option dialog */
 	dialog = brasero_burn_options_new (session);
-	if (window)
-		gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
+
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
+
+	if (dialog_title)
+		gtk_window_set_title (GTK_WINDOW (dialog), dialog_title);
 
 	if (options)
 		brasero_burn_options_add_options (BRASERO_BURN_OPTIONS (dialog), options);
@@ -124,8 +141,11 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 
 	/* now run burn dialog */
 	dialog = brasero_burn_dialog_new ();
-	if (window)
-		gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
+
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), icon_name);
+
+	if (dialog_title)
+		gtk_window_set_title (GTK_WINDOW (dialog), dialog_title);
 
 	brasero_session_cfg_disable (session);
 
@@ -163,7 +183,7 @@ nautilus_disc_burn_is_empty (GtkWindow *toplevel)
 			return TRUE;
 		}
 
-		string = g_strdup_printf ("%s.", _("An internal error occured"));
+		string = g_strdup_printf ("%s.", _("An internal error occurred"));
 		brasero_utils_message_dialog (GTK_WIDGET (toplevel),
 					      string,
 					      error ? error->message:NULL,
@@ -242,7 +262,10 @@ write_activate (GtkWindow *toplevel)
 	gtk_widget_show_all (options);
 
 	/* NOTE: set the disc we're handling */
-	launch_brasero_on_window_session (session, options, toplevel);
+	launch_brasero_on_window_session (session,
+	                                  _("CD/DVD Creator"),
+	                                  options,
+	                                  toplevel);
 
 	/* cleanup */
 	g_object_unref (session);
@@ -257,6 +280,7 @@ write_activate_cb (NautilusMenuItem *item,
 
 static void
 launch_brasero_on_window_track (BraseroTrack	*track,
+                                const gchar	*dialog_title,
 				GtkWidget	*options,
 				GtkWindow	*window)
 {
@@ -268,7 +292,10 @@ launch_brasero_on_window_track (BraseroTrack	*track,
 					BRASERO_TRACK (track),
 					NULL);
 
-	launch_brasero_on_window_session (session, options, window);
+	launch_brasero_on_window_session (session,
+	                                  dialog_title,
+	                                  options,
+	                                  window);
 	g_object_unref (session);
 }
 
@@ -286,7 +313,10 @@ write_iso_activate_cb (NautilusMenuItem *item,
 	track = brasero_track_image_cfg_new ();
 	brasero_track_image_cfg_set_source (track, uri);
 
-	launch_brasero_on_window_track (BRASERO_TRACK (track), NULL, GTK_WINDOW (user_data));
+	launch_brasero_on_window_track (BRASERO_TRACK (track),
+	                                _("Write to Disc"),
+	                                NULL,
+	                                GTK_WINDOW (user_data));
 	g_object_unref (track);
 }
 
@@ -308,7 +338,10 @@ copy_disc_activate_cb (NautilusMenuItem *item,
 	brasero_track_disc_set_drive (track, drive);
 	g_object_unref (drive);
 
-	launch_brasero_on_window_track (BRASERO_TRACK (track), NULL, GTK_WINDOW (user_data));
+	launch_brasero_on_window_track (BRASERO_TRACK (track),
+	                                _("Copy Disc"),
+	                                NULL,
+	                                GTK_WINDOW (user_data));
 	g_object_unref (track);
 }
 
@@ -337,7 +370,12 @@ tool_dialog_run (BraseroToolDialog	*dialog,
 		g_object_unref (drive);
 	}
 
-	gtk_widget_show (GTK_WIDGET (dialog));
+	/* Get the icon for the window */
+	if (toplevel)
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), gtk_window_get_icon_name (toplevel));
+	else
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), "brasero");
+
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
@@ -493,8 +531,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
         if (is_iso) {
                 /* Whether or not this file is local is not a problem */
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_iso",
-                                               _("_Write to Disc..."),
-                                               _("Write disc image to a CD or DVD disc"),
+                                               _("_Write to Disc…"),
+                                               _("Write disc image to a CD or DVD"),
                                                "media-optical-data-new");
                 g_object_set_data (G_OBJECT (item), "file_info", file_info);
                 g_object_set_data (G_OBJECT (item), "window", window);
@@ -562,8 +600,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		if (brasero_burn_library_input_supported (type) == BRASERO_BURN_OK) {
 			/* user may want to copy it ... */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::copy_disc",
-						       _("_Copy Disc..."),
-						       _("Create a copy of this CD or DVD disc"),
+						       _("_Copy Disc…"),
+						       _("Create a copy of this CD or DVD"),
 						       "media-optical-copy");
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -576,8 +614,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		if (brasero_burn_library_get_media_capabilities (media) & BRASERO_MEDIUM_REWRITABLE) {
 			/* ... or if it's a rewritable medium to blank it ... */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::blank_disc",
-						       _("_Blank Disc..."),
-						       _("Blank this CD or DVD disc"),
+						       _("_Blank Disc…"),
+						       _("Blank this CD or DVD"),
 						       "media-optical-blank");
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -593,8 +631,8 @@ nautilus_disc_burn_get_file_items (NautilusMenuProvider *provider,
 		&& (media & BRASERO_MEDIUM_HAS_DATA)) {
 			/* ... or verify medium. */
 			item = nautilus_menu_item_new ("NautilusDiscBurn::check_disc",
-						       _("_Check Disc..."),
-						       _("Check the data integrity on this CD or DVD disc"),
+						       _("_Check Disc…"),
+						       _("Check the data integrity on this CD or DVD"),
 						       NULL);
 			g_object_set_data (G_OBJECT (item), "file_info", file_info);
 			g_object_set_data (G_OBJECT (item), "window", window);
@@ -639,8 +677,8 @@ nautilus_disc_burn_get_background_items (NautilusMenuProvider *provider,
                 NautilusMenuItem *item;
 
                 item = nautilus_menu_item_new ("NautilusDiscBurn::write_menu",
-                                               _("_Write to Disc..."),
-                                               _("Write contents to a CD or DVD disc"),
+                                               _("_Write to Disc…"),
+                                               _("Write contents to a CD or DVD"),
                                                "brasero");
                 g_signal_connect (item, "activate",
                                   G_CALLBACK (write_activate_cb),
@@ -941,10 +979,20 @@ nautilus_disc_burn_register_type (GTypeModule *module)
 void
 nautilus_module_initialize (GTypeModule *module)
 {
+	GConfClient *client;
+
         DEBUG_PRINT ("Initializing nautilus-disc-recorder\n");
 
-        brasero_media_library_start ();
+	client = gconf_client_get_default ();
+	if (gconf_client_get_bool (client, "/apps/brasero/nautilus-extension-debug", NULL)) {
+		brasero_media_library_set_debug (TRUE);
+		brasero_burn_library_set_debug (TRUE);
+	}
+	g_object_unref (client);
+
+	brasero_media_library_start ();
         brasero_burn_library_start (NULL, NULL);
+
         DEBUG_PRINT ("Libbrasero-media started\n");
 
         nautilus_disc_burn_register_type (module);
