@@ -111,6 +111,18 @@ void
 brasero_app_check (BraseroApp *app,
 		   const gchar *device);
 
+gboolean
+brasero_app_open_project (BraseroApp *app,
+                          const gchar *uri,
+                          gboolean is_playlist,
+                          gboolean warn_user,
+                          gboolean burn);
+
+gboolean
+brasero_app_open_uri (BraseroApp *app,
+                      const gchar *uri_arg,
+                      gboolean warn_user);
+
 GtkWidget *
 brasero_app_get_statusbar1 (BraseroApp *app);
 
