@@ -41,6 +41,9 @@
 
 #include "brasero-misc.h"
 #include "brasero-io.h"
+#include "brasero-notify.h"
+
+#include "brasero-units.h"
 
 #include "brasero-tags.h"
 #include "brasero-track-stream-cfg.h"
@@ -130,6 +133,7 @@ struct _BraseroAudioDiscPrivate {
 
 	GtkWidget *tree;
 
+	GtkWidget *message;
 	GtkUIManager *manager;
 	GtkActionGroup *disc_group;
 
@@ -149,7 +153,7 @@ static GtkActionEntry entries[] = {
 	{"ContextualMenu", NULL, N_("Menu")},
 	{"OpenSong", GTK_STOCK_OPEN, NULL, NULL, N_("Open the selected files"),
 	 G_CALLBACK (brasero_audio_disc_open_activated_cb)},
-	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Information..."), NULL, N_("Edit the track information (start, end, author, ...)"),
+	{"EditSong", GTK_STOCK_PROPERTIES, N_("_Edit Information…"), NULL, N_("Edit the track information (start, end, author, etc.)"),
 	 G_CALLBACK (brasero_audio_disc_edit_information_cb)},
 	{"DeleteAudio", GTK_STOCK_REMOVE, NULL, NULL, N_("Remove the selected files from the project"),
 	 G_CALLBACK (brasero_audio_disc_delete_activated_cb)},
@@ -157,7 +161,7 @@ static GtkActionEntry entries[] = {
 	 G_CALLBACK (brasero_audio_disc_paste_activated_cb)},
 	{"Pause", "insert-pause", N_("I_nsert a Pause"), NULL, N_("Add a 2 second pause after the track"),
 	 G_CALLBACK (brasero_audio_disc_add_pause_cb)},
-	{"Split", "transform-crop-and-resize", N_("_Split Track..."), NULL, N_("Split the selected track"),
+	{"Split", "transform-crop-and-resize", N_("_Split Track…"), NULL, N_("Split the selected track"),
 	 G_CALLBACK (brasero_audio_disc_split_cb)}
 };
 
@@ -215,10 +219,10 @@ enum {
 	PROP_REJECT_FILE,
 };
 
-/* 1 sec = 75 sectors, len is in nanosecond */
-#define BRASERO_SECTORS_TO_TIME(sectors)	(gint64) (sectors * GST_SECOND / 75)
 #define COL_KEY "column_key"
 
+#define BRASERO_AUDIO_DISC_CONTEXT		1000
+
 static void brasero_audio_disc_iface_disc_init (BraseroDiscIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (BraseroAudioDisc,
@@ -301,6 +305,13 @@ brasero_audio_disc_add_ui (BraseroDisc *disc,
 
 	audio_disc = BRASERO_AUDIO_DISC (disc);
 
+	if (audio_disc->priv->message) {
+		g_object_unref (audio_disc->priv->message);
+		audio_disc->priv->message = NULL;
+	}
+
+	audio_disc->priv->message = g_object_ref (message);
+
 	if (!audio_disc->priv->disc_group) {
 		audio_disc->priv->disc_group = gtk_action_group_new (BRASERO_DISC_ACTION "-audio");
 		gtk_action_group_set_translation_domain (audio_disc->priv->disc_group, GETTEXT_PACKAGE);
@@ -517,6 +528,9 @@ brasero_audio_disc_reset_real (BraseroAudioDisc *disc)
 		gtk_tree_path_free (disc->priv->selected_path);
 		disc->priv->selected_path = NULL;
 	}
+
+	if (disc->priv->message)
+		brasero_notify_message_remove (BRASERO_NOTIFY (disc->priv->message), BRASERO_AUDIO_DISC_CONTEXT);
 }
 
 static void
@@ -532,6 +546,11 @@ brasero_audio_disc_finalize (GObject *object)
 	cobj->priv->add_dir = NULL;
 	cobj->priv->add_playlist = NULL;
 
+	if (cobj->priv->message) {
+		g_object_unref (cobj->priv->message);
+		cobj->priv->message = NULL;
+	}
+
 	if (cobj->priv->manager) {
 		g_object_unref (cobj->priv->manager);
 		cobj->priv->manager = NULL;
@@ -595,7 +614,7 @@ brasero_audio_disc_add_uri_real (BraseroAudioDisc *disc,
 	brasero_track_stream_set_boundaries (BRASERO_TRACK_STREAM (track),
 					     start,
 					     end,
-					     BRASERO_SECTORS_TO_TIME (gap_sectors));
+					     BRASERO_SECTORS_TO_DURATION (gap_sectors));
 
 	session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (store));
 	if (pos > 0) {
@@ -621,7 +640,7 @@ brasero_audio_disc_file_type_error_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	primary = g_strdup_printf (_("\"%s\" could not be handled by Gstreamer."), name);
+	primary = g_strdup_printf (_("\"%s\" could not be handled by GStreamer."), name);
 	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   _("Make sure the appropriate codec is installed"),
@@ -640,7 +659,7 @@ brasero_audio_disc_video_file_dialog (BraseroAudioDisc *disc,
 	gchar *name;
 
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	string = g_strdup_printf (_("Do you want to add \"%s\" which is a video file?"), name);
+	string = g_strdup_printf (_("Do you want to add \"%s\", which is a video file?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -798,6 +817,70 @@ brasero_audio_disc_unreadable_dialog (BraseroAudioDisc *disc,
 	g_free (name);
 }
 
+static void
+brasero_audio_disc_wav_dts_response_cb (GtkButton *button,
+                                        GtkResponseType response,
+                                        BraseroAudioDisc *disc)
+{
+	BraseroSessionCfg *session;
+	GtkTreeModel *model;
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (disc->priv->tree));
+	session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (model));
+
+	if (response == GTK_RESPONSE_OK)
+		brasero_burn_session_tag_add_int (BRASERO_BURN_SESSION (session),
+		                                  BRASERO_SESSION_STREAM_AUDIO_FORMAT,
+		                                  BRASERO_AUDIO_FORMAT_DTS);
+}
+
+static void
+brasero_audio_disc_wav_dts_file_dialog (BraseroAudioDisc *disc)
+{
+	GtkWidget *message;
+	BraseroSessionCfg *session;
+	GtkTreeModel *model;
+
+	if (brasero_notify_get_message_by_context_id (BRASERO_NOTIFY (disc->priv->message),
+	                                              BRASERO_AUDIO_DISC_CONTEXT))
+		return;
+
+	/* Add a tag (RAW by default) so that we won't try to display this message again */
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (disc->priv->tree));
+	session = brasero_video_tree_model_get_session (BRASERO_VIDEO_TREE_MODEL (model));
+	brasero_burn_session_tag_add_int (BRASERO_BURN_SESSION (session),
+	                                  BRASERO_SESSION_STREAM_AUDIO_FORMAT,
+	                                  BRASERO_AUDIO_FORMAT_RAW);
+
+	message = brasero_notify_message_add (BRASERO_NOTIFY (disc->priv->message),
+					      _("Do you want to create an audio CD with DTS tracks?"),
+					      _("Some of the selected songs are suitable for creating DTS tracks."
+					        "\nThis type of audio CD track provides a higher quality of sound but can only be played by specific digital players."
+					        "\nNote: if you agree, normalization will not be applied to these tracks."),
+					      0,
+					      BRASERO_AUDIO_DISC_CONTEXT);
+
+	brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),
+					GTK_MESSAGE_INFO);
+
+	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
+				   BRASERO_DISC_MESSAGE (message),
+				   _("Create _Regular Tracks"),
+				   _("Click here to burn all songs as regular tracks"),
+				   GTK_RESPONSE_NO);
+
+	brasero_notify_button_add (BRASERO_NOTIFY (disc->priv->message),
+				   BRASERO_DISC_MESSAGE (message),
+				   _("Create _DTS Tracks"),
+				   _("Click here to burn all suitable songs as DTS tracks"),
+				   GTK_RESPONSE_OK);
+
+	g_signal_connect (BRASERO_DISC_MESSAGE (message),
+			  "response",
+			  G_CALLBACK (brasero_audio_disc_wav_dts_response_cb),
+			  disc);
+}
+
 static void
 brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 				    BraseroAudioDisc *self)
@@ -806,12 +889,14 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 	GSList *tracks;
 	gboolean notready;
 	BraseroStatus *status;
+	gboolean should_use_dts;
 
 	if (!GTK_WIDGET (self)->window)
 		return;
 
 	/* make sure all tracks have video */
 	notready = FALSE;
+	should_use_dts = FALSE;
 	status = brasero_status_new ();
 	tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (session));
 	for (; tracks; tracks = next) {
@@ -888,9 +973,11 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 			continue;
 		}
 
+		if ((format & BRASERO_AUDIO_FORMAT_DTS) != 0)
+			should_use_dts = TRUE;
+
 		if (BRASERO_STREAM_FORMAT_HAS_VIDEO (format)) {
 			gboolean res;
-
 			gchar *uri;
 
 			uri = brasero_track_stream_get_source (track, TRUE);
@@ -901,7 +988,11 @@ brasero_audio_disc_session_changed (BraseroSessionCfg *session,
 			g_free (uri);
 		}
 	}
-	brasero_status_free (status);
+	g_object_unref (status);
+
+	if (should_use_dts
+	&&  brasero_burn_session_tag_lookup (BRASERO_BURN_SESSION (session), BRASERO_SESSION_STREAM_AUDIO_FORMAT, NULL) != BRASERO_BURN_OK)
+		brasero_audio_disc_wav_dts_file_dialog (self);
 }
 
 static BraseroDiscResult
@@ -911,7 +1002,7 @@ brasero_audio_disc_add_uri (BraseroDisc *disc,
 	GtkTreePath *treepath = NULL;
 	BraseroAudioDisc *audio_disc;
 	BraseroDiscResult result;
-g_print ("RECEIVED\n");
+
 	audio_disc = BRASERO_AUDIO_DISC (disc);
 	result = brasero_audio_disc_add_uri_real (audio_disc,
 						  uri,
@@ -1519,8 +1610,8 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
         /* information about the track */
         gtk_tree_model_get_iter (model, &iter, treepath);
         gtk_tree_model_get (model, &iter,
-                            BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
-                            -1);
+                                         BRASERO_VIDEO_TREE_MODEL_INDEX_NUM, &track_num,
+                                         -1);
         brasero_track_stream_get_length (BRASERO_TRACK_STREAM (track), &length);
 
 	/* set up dialog */
@@ -1561,9 +1652,9 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
 					   &gap);
 
 	brasero_track_stream_set_boundaries (BRASERO_TRACK_STREAM (track),
-                                             start,
-                                             end,
-                                             gap);
+                                                                      start,
+                                                                      end,
+                                                                      BRASERO_SECTORS_TO_DURATION (gap));
 
 	if (title)
 		brasero_track_tag_add_string (BRASERO_TRACK (track),
@@ -1585,7 +1676,7 @@ brasero_audio_disc_edit_single_song_properties (BraseroAudioDisc *disc,
 					   BRASERO_TRACK_STREAM_ISRC_TAG,
 					   isrc);
 
-	if (end - start + BRASERO_SECTORS_TO_TIME (gap) < BRASERO_MIN_STREAM_LENGTH)
+	if (end - start + BRASERO_SECTORS_TO_DURATION (gap) < BRASERO_MIN_STREAM_LENGTH)
 		brasero_audio_disc_short_track_dialog (disc);
 
 	g_free (title);
