@@ -851,8 +851,6 @@ brasero_data_disc_2G_file_cb (BraseroTrackDataCfg *project,
 						    "\nHowever, Mac OS X cannot read images created with version 3 of the ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Al_ways Add Such File"), GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_show_all (dialog);
@@ -896,8 +894,6 @@ brasero_data_disc_deep_directory_cb (BraseroTrackDataCfg *project,
 						    "\nNote: Such a file hierarchy is known to work on Linux."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Ne_ver Add Such File"), GTK_RESPONSE_REJECT);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Al_ways Add Such File"), GTK_RESPONSE_ACCEPT);
 
 	gtk_widget_show_all (dialog);
@@ -1463,14 +1459,14 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 	brasero_track_get_status (BRASERO_TRACK (track), status);
 
 	if (brasero_status_get_result (status) == BRASERO_BURN_OK) {
-		brasero_status_free (status);
+		g_object_unref (status);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->tree), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (priv->filter), TRUE);
 		return BRASERO_DISC_OK;
 	}
 
 	if (brasero_status_get_result (status) != BRASERO_BURN_NOT_READY) {
-		brasero_status_free (status);
+		g_object_unref (status);
 		return BRASERO_DISC_ERROR_UNKNOWN;
 	}
 
@@ -1497,7 +1493,7 @@ brasero_data_disc_set_track (BraseroDataDisc *disc,
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->tree), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (priv->filter), FALSE);
 
-	brasero_status_free (status);
+	g_object_unref (status);
 	return BRASERO_DISC_OK;
 }
 
