@@ -35,14 +35,14 @@
 
 #include <gtk/gtk.h>
 
-#include <gconf/gconf-client.h>
-
 #include "brasero-misc.h"
 #include "brasero-metadata.h"
 #include "brasero-io.h"
 
 #include "brasero-units.h"
 
+#include "brasero-setting.h"
+
 #include "brasero-player.h"
 #include "brasero-player-bacon.h"
 #include "brasero-utils.h"
@@ -89,11 +89,6 @@ struct BraseroPlayerPrivate {
 	gint64 length;
 };
 
-#define GCONF_IMAGE_SIZE_WIDTH	"/apps/brasero/display/image_width"
-#define GCONF_IMAGE_SIZE_HEIGHT	"/apps/brasero/display/image_height"
-#define GCONF_VIDEO_SIZE_WIDTH	"/apps/brasero/display/video_width"
-#define GCONF_VIDEO_SIZE_HEIGHT	"/apps/brasero/display/video_height"
-
 typedef enum {
 	READY_SIGNAL,
 	ERROR_SIGNAL,
@@ -501,14 +496,15 @@ brasero_player_create_controls_stream (BraseroPlayer *player,
 				    0);
 
 		hbox = gtk_hbox_new (FALSE, 0);
-
+		alignment = gtk_alignment_new (1.0, 0.0, 0.0, 0.0);
+		player->priv->button = gtk_button_new ();
 		gtk_container_add (GTK_CONTAINER (alignment), hbox);
 		gtk_box_pack_start (GTK_BOX (box),
 				    alignment,
 				    TRUE,
 				    TRUE,
 				    0);
-		
+
 		image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_BUTTON);
 		zoom = gtk_button_new ();
 		gtk_button_set_image (GTK_BUTTON (zoom), image);
@@ -809,7 +805,7 @@ brasero_player_image (BraseroPlayer *player)
 	gtk_label_set_markup (GTK_LABEL (player->priv->header), string);
 	g_free (string);
 
-	string = g_strdup_printf (_("<span weight=\"bold\">Size:</span>\t<i><span size=\"smaller\"> %i x %i pixels</span></i>"), width, height);
+	string = g_strdup_printf (_("<span weight=\"bold\">Size:</span>\t<i><span size=\"smaller\"> %i \303\227 %i pixels</span></i>"), width, height);
 	gtk_label_set_markup (GTK_LABEL (player->priv->size), string);
 	g_free (string);
 
@@ -900,7 +896,8 @@ brasero_player_metadata_completed (GObject *obj,
 		/* video */
 		brasero_player_create_controls_stream (player, TRUE);
 		gtk_range_set_value (GTK_RANGE (player->priv->progress), 0.0);
-		if (g_file_info_get_attribute_boolean (info,BRASERO_IO_IS_SEEKABLE))
+
+		if (g_file_info_get_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE))
 			gtk_widget_set_sensitive (player->priv->progress, TRUE);
 		else
 			gtk_widget_set_sensitive (player->priv->progress, FALSE);
@@ -922,6 +919,7 @@ brasero_player_metadata_completed (GObject *obj,
 		brasero_player_create_controls_stream (player, FALSE);
 		gtk_widget_hide (player->priv->notebook);
 		gtk_range_set_value (GTK_RANGE (player->priv->progress), 0.0);
+
 		if (g_file_info_get_attribute_boolean (info, BRASERO_IO_IS_SEEKABLE))
 			gtk_widget_set_sensitive (player->priv->progress, TRUE);
 		else
@@ -1116,7 +1114,7 @@ brasero_player_eof_cb (BraseroPlayerBacon *bacon, BraseroPlayer *player)
 	gtk_image_set_from_stock (GTK_IMAGE (player->priv->image),
 				  GTK_STOCK_MEDIA_PLAY,
 				  GTK_ICON_SIZE_BUTTON);
-
+	
 	if (player->priv->update_scale_id) {
 		g_source_remove (player->priv->update_scale_id);
 		player->priv->update_scale_id = 0;
@@ -1252,33 +1250,21 @@ static void
 brasero_player_destroy (GtkObject *obj)
 {
 	BraseroPlayer *player;
-	GConfClient *client;
 
 	player = BRASERO_PLAYER (obj);
 
-	client = gconf_client_get_default ();
-
-	gconf_client_set_int (client,
-			      GCONF_IMAGE_SIZE_WIDTH,
-			      player->priv->image_width,
-			      NULL);
-
-	gconf_client_set_int (client,
-			      GCONF_IMAGE_SIZE_HEIGHT,
-			      player->priv->image_height,
-			      NULL);
-
-	gconf_client_set_int (client,
-			      GCONF_VIDEO_SIZE_WIDTH,
-			      player->priv->video_width,
-			      NULL);
-
-	gconf_client_set_int (client,
-			      GCONF_VIDEO_SIZE_HEIGHT,
-			      player->priv->video_height,
-			      NULL);
-
-	g_object_unref (client);
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_IMAGE_SIZE_WIDTH,
+	                           GINT_TO_POINTER (player->priv->image_width));
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_IMAGE_SIZE_HEIGHT,
+	                           GINT_TO_POINTER (player->priv->image_height));
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_VIDEO_SIZE_WIDTH,
+	                           GINT_TO_POINTER (player->priv->video_width));
+	brasero_setting_set_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_VIDEO_SIZE_WIDTH,
+	                           GINT_TO_POINTER (player->priv->video_width));
 
 	player->priv->image = NULL;
 
@@ -1354,7 +1340,7 @@ static void
 brasero_player_init (BraseroPlayer *obj)
 {
 	GtkWidget *alignment;
-	GConfClient *client;
+	gpointer value;
 
 	obj->priv = g_new0 (BraseroPlayerPrivate, 1);
 
@@ -1406,34 +1392,37 @@ brasero_player_init (BraseroPlayer *obj)
 				  obj->priv->bacon,
 				  NULL);
 
-	client = gconf_client_get_default ();
-	obj->priv->image_width = gconf_client_get_int (client,
-						       GCONF_IMAGE_SIZE_WIDTH,
-						       NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_IMAGE_SIZE_WIDTH,
+	                           &value);
+	obj->priv->image_width = GPOINTER_TO_INT (value);
 
 	if (obj->priv->image_width > PLAYER_BACON_WIDTH * 3
 	||  obj->priv->image_width < PLAYER_BACON_WIDTH)
 		obj->priv->image_width = PLAYER_BACON_WIDTH;
 
-	obj->priv->image_height = gconf_client_get_int (client,
-						        GCONF_IMAGE_SIZE_HEIGHT,
-						        NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_IMAGE_SIZE_HEIGHT,
+	                           &value);
+	obj->priv->image_height = GPOINTER_TO_INT (value);
 
 	if (obj->priv->image_height > PLAYER_BACON_HEIGHT * 3
 	||  obj->priv->image_height < PLAYER_BACON_HEIGHT)
 		obj->priv->image_height = PLAYER_BACON_HEIGHT;
 
-	obj->priv->video_width = gconf_client_get_int (client,
-						       GCONF_VIDEO_SIZE_WIDTH,
-						       NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_VIDEO_SIZE_WIDTH,
+	                           &value);
+	obj->priv->video_width = GPOINTER_TO_INT (value);
 
 	if (obj->priv->video_width > PLAYER_BACON_WIDTH * 3
 	||  obj->priv->video_width < PLAYER_BACON_WIDTH)
 		obj->priv->video_width = PLAYER_BACON_WIDTH;
 
-	obj->priv->video_height = gconf_client_get_int (client,
-							GCONF_VIDEO_SIZE_HEIGHT,
-							NULL);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_VIDEO_SIZE_HEIGHT,
+	                           &value);
+	obj->priv->video_height = GPOINTER_TO_INT (value);
 
 	if (obj->priv->video_height > PLAYER_BACON_HEIGHT * 3
 	||  obj->priv->video_height < PLAYER_BACON_HEIGHT)
@@ -1442,7 +1431,6 @@ brasero_player_init (BraseroPlayer *obj)
 	gtk_widget_set_size_request (obj->priv->bacon,
 				     obj->priv->video_width,
 				     obj->priv->video_height);
-	g_object_unref (client);
 }
 
 GtkWidget *
