@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /***************************************************************************
 *            play-list.c
 *
@@ -29,8 +30,6 @@
 #  include <config.h>
 #endif
 
-#ifdef BUILD_PLAYLIST
-
 #include <string.h>
 
 #include <glib.h>
@@ -41,10 +40,6 @@
 
 #include <gtk/gtk.h>
 
-#ifdef BUILD_SEARCH
-#include <beagle/beagle.h>
-#endif
-
 #include <totem-pl-parser.h>
 
 #include "brasero-misc.h"
@@ -53,6 +48,7 @@
 
 #include "brasero-app.h"
 #include "brasero-playlist.h"
+#include "brasero-search-engine.h"
 #include "brasero-utils.h"
 #include "brasero-metadata.h"
 #include "brasero-io.h"
@@ -61,20 +57,10 @@
 #include "brasero-uri-container.h"
 #include "brasero-layout-object.h"
 
-static void brasero_playlist_class_init (BraseroPlaylistClass *klass);
-static void brasero_playlist_init (BraseroPlaylist *sp);
-static void brasero_playlist_iface_uri_container_init (BraseroURIContainerIFace *iface);
-static void brasero_playlist_iface_layout_object_init (BraseroLayoutObjectIFace *iface);
-static void brasero_playlist_finalize (GObject *object);
-static void brasero_playlist_destroy (GtkObject *object);
 
 struct BraseroPlaylistPrivate {
-
-#ifdef BUILD_SEARCH
-	BeagleClient *client;
-	BeagleQuery *query;
+	BraseroSearchEngine *engine;
 	int id;
-#endif
 
 	GtkWidget *tree;
 	GtkWidget *button_add;
@@ -96,56 +82,6 @@ enum {
 	BRASERO_PLAYLIST_NB_COL,
 };
 
-#ifdef BUILD_SEARCH
-
-static void brasero_playlist_beagle_hit_added_cb (BeagleQuery *query,
-						  BeagleHitsAddedResponse *response,
-						  BraseroPlaylist *playlist);
-static void brasero_playlist_beagle_hit_substracted_cb (BeagleQuery *query,
-							BeagleHitsSubtractedResponse *response,
-							BraseroPlaylist *playlist);
-static void brasero_playlist_beagle_finished_cb (BeagleQuery *query,
-						 BeagleFinishedResponse *response,
-						 BraseroPlaylist *playlist);
-#endif
-
-static void brasero_playlist_drag_data_get_cb (GtkTreeView *tree,
-					       GdkDragContext *drag_context,
-					       GtkSelectionData *selection_data,
-					       guint info,
-					       guint time,
-					       BraseroPlaylist *playlist);
-static void brasero_playlist_add_cb (GtkButton *button,
-				     BraseroPlaylist *playlist);
-static void brasero_playlist_remove_cb (GtkButton *button,
-					BraseroPlaylist *playlist);
-static void brasero_playlist_add_uri_playlist (BraseroPlaylist *playlist,
-					       const char *uri,
-					       gboolean quiet);
-static void brasero_playlist_search_playlists_rhythmbox (BraseroPlaylist *playlist);
-static void brasero_playlist_increase_activity_counter (BraseroPlaylist *playlist);
-static void brasero_playlist_decrease_activity_counter (BraseroPlaylist *playlist);
-static void brasero_playlist_row_activated_cb (GtkTreeView *tree,
-					       GtkTreeIter *row,
-					       GtkTreeViewColumn *column,
-					       BraseroPlaylist *playlist);
-static void brasero_playlist_selection_changed_cb (GtkTreeSelection *
-						   selection,
-						   BraseroPlaylist *
-						   playlist);
-static gchar **brasero_playlist_get_selected_uris_real (BraseroPlaylist *playlist);
-
-static gchar **
-brasero_playlist_get_selected_uris (BraseroURIContainer *container);
-static gchar *
-brasero_playlist_get_selected_uri (BraseroURIContainer *container);
-
-static void
-brasero_playlist_get_proportion (BraseroLayoutObject *object,
-				 gint *header,
-				 gint *center,
-				 gint *footer);
-
 enum {
 	TARGET_URIS_LIST,
 };
@@ -155,80 +91,19 @@ static GtkTargetEntry ntables[] = {
 };
 static guint nb_ntables = sizeof (ntables) / sizeof (ntables[0]);
 
-static GObjectClass *parent_class = NULL;
+static void brasero_playlist_iface_uri_container_init (BraseroURIContainerIFace *iface);
+static void brasero_playlist_iface_layout_object_init (BraseroLayoutObjectIFace *iface);
+
+G_DEFINE_TYPE_WITH_CODE (BraseroPlaylist,
+			 brasero_playlist,
+			 GTK_TYPE_VBOX,
+			 G_IMPLEMENT_INTERFACE (BRASERO_TYPE_URI_CONTAINER,
+					        brasero_playlist_iface_uri_container_init)
+			 G_IMPLEMENT_INTERFACE (BRASERO_TYPE_LAYOUT_OBJECT,
+					        brasero_playlist_iface_layout_object_init));
 
 #define BRASERO_PLAYLIST_SPACING 6
 
-GType
-brasero_playlist_get_type ()
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo our_info = {
-			sizeof (BraseroPlaylistClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) brasero_playlist_class_init,
-			NULL,
-			NULL,
-			sizeof (BraseroPlaylist),
-			0,
-			(GInstanceInitFunc) brasero_playlist_init,
-		};
-
-		static const GInterfaceInfo uri_container_info =
-		{
-			(GInterfaceInitFunc) brasero_playlist_iface_uri_container_init,
-			NULL,
-			NULL
-		};
-		static const GInterfaceInfo layout_object_info =
-		{
-			(GInterfaceInitFunc) brasero_playlist_iface_layout_object_init,
-			NULL,
-			NULL
-		};
-
-		type = g_type_register_static (GTK_TYPE_VBOX,
-					       "BraseroPlaylist",
-					       &our_info, 0);
-
-		g_type_add_interface_static (type,
-					     BRASERO_TYPE_URI_CONTAINER,
-					     &uri_container_info);
-		g_type_add_interface_static (type,
-					     BRASERO_TYPE_LAYOUT_OBJECT,
-					     &layout_object_info);
-	}
-
-	return type;
-}
-
-static void
-brasero_playlist_class_init (BraseroPlaylistClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
-
-	parent_class = g_type_class_peek_parent (klass);
-	object_class->finalize = brasero_playlist_finalize;
-	gtkobject_class->destroy = brasero_playlist_destroy;
-}
-
-static void
-brasero_playlist_iface_uri_container_init (BraseroURIContainerIFace *iface)
-{
-	iface->get_selected_uri = brasero_playlist_get_selected_uri;
-	iface->get_selected_uris = brasero_playlist_get_selected_uris;
-}
-
-static void
-brasero_playlist_iface_layout_object_init (BraseroLayoutObjectIFace *iface)
-{
-	iface->get_proportion = brasero_playlist_get_proportion;
-}
-
 static void
 brasero_playlist_get_proportion (BraseroLayoutObject *object,
 				 gint *header,
@@ -242,141 +117,6 @@ brasero_playlist_get_proportion (BraseroLayoutObject *object,
 	(*footer) = requisition.height + BRASERO_PLAYLIST_SPACING;
 }
 
-static void
-brasero_playlist_init (BraseroPlaylist *obj)
-{
-	GtkWidget *hbox, *scroll;
-	GtkTreeStore *store = NULL;
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-
-	obj->priv = g_new0 (BraseroPlaylistPrivate, 1);
-	gtk_box_set_spacing (GTK_BOX (obj), BRASERO_PLAYLIST_SPACING);
-
-	hbox = gtk_hbox_new (FALSE, 8);
-	gtk_widget_show (hbox);
-
-	obj->priv->button_add = gtk_button_new_from_stock (GTK_STOCK_ADD);
-	gtk_widget_show (obj->priv->button_add);
-	gtk_box_pack_end (GTK_BOX (hbox),
-			  obj->priv->button_add,
-			  FALSE,
-			  FALSE,
-			  0);
-	g_signal_connect (G_OBJECT (obj->priv->button_add),
-			  "clicked",
-			  G_CALLBACK (brasero_playlist_add_cb),
-			  obj);
-
-	obj->priv->button_remove = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
-	gtk_widget_show (obj->priv->button_remove);
-	gtk_box_pack_end (GTK_BOX (hbox),
-			  obj->priv->button_remove,
-			  FALSE,
-			  FALSE,
-			  0);
-	g_signal_connect (G_OBJECT (obj->priv->button_remove),
-			  "clicked",
-			  G_CALLBACK (brasero_playlist_remove_cb),
-			  obj);
-
-	gtk_box_pack_end (GTK_BOX (obj), hbox, FALSE, FALSE, 0);
-
-	store = gtk_tree_store_new (BRASERO_PLAYLIST_NB_COL,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING,
-				    G_TYPE_STRING, 
-				    G_TYPE_STRING,
-				    G_TYPE_INT64);
-
-	obj->priv->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
-	egg_tree_multi_drag_add_drag_support (GTK_TREE_VIEW (obj->priv->tree));
-
-	gtk_tree_view_set_enable_tree_lines (GTK_TREE_VIEW (obj->priv->tree), TRUE);
-	gtk_tree_view_set_rubber_banding (GTK_TREE_VIEW (obj->priv->tree), TRUE);
-	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (obj->priv->tree), TRUE);
-	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (obj->priv->tree), TRUE);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (obj->priv->tree), TRUE);
-	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (obj->priv->tree),
-					   BRASERO_PLAYLIST_DISPLAY_COL);
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Playlists"),
-							   renderer, "text",
-							   BRASERO_PLAYLIST_DISPLAY_COL,
-							   NULL);
-	gtk_tree_view_column_set_sort_column_id (column,
-						 BRASERO_PLAYLIST_DISPLAY_COL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-	gtk_tree_view_column_set_expand (column, TRUE);
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Number of Songs"),
-							   renderer, "text",
-							   BRASERO_PLAYLIST_NB_SONGS_COL,
-							   NULL);
-	gtk_tree_view_column_set_sort_column_id (column,
-						 BRASERO_PLAYLIST_NB_SONGS_COL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Length"),
-							   renderer, "text",
-							   BRASERO_PLAYLIST_LEN_COL,
-							   NULL);
-	gtk_tree_view_column_set_sort_column_id (column,
-						 BRASERO_PLAYLIST_LEN_COL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Genre"), renderer,
-							   "text",
-							   BRASERO_PLAYLIST_GENRE_COL,
-							   NULL);
-	gtk_tree_view_column_set_sort_column_id (column,
-						 BRASERO_PLAYLIST_GENRE_COL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
-				     column);
-
-	gtk_tree_view_set_search_column (GTK_TREE_VIEW (obj->priv->tree),
-					 BRASERO_PLAYLIST_DISPLAY_COL);
-	gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (obj->priv->tree),
-						GDK_BUTTON1_MASK, ntables,
-						nb_ntables,
-						GDK_ACTION_COPY |
-						GDK_ACTION_MOVE);
-
-	g_signal_connect (G_OBJECT (obj->priv->tree), "drag_data_get",
-			  G_CALLBACK (brasero_playlist_drag_data_get_cb),
-			  obj);
-
-	g_signal_connect (G_OBJECT (obj->priv->tree), "row_activated",
-			  G_CALLBACK (brasero_playlist_row_activated_cb),
-			  obj);
-
-	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (obj->priv->tree))),
-			  "changed",
-			  G_CALLBACK (brasero_playlist_selection_changed_cb),
-			  obj);
-
-	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (obj->priv->tree)),
-				     GTK_SELECTION_MULTIPLE);
-
-	scroll = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
-					GTK_POLICY_AUTOMATIC,
-					GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-					     GTK_SHADOW_IN);
-
-	gtk_container_add (GTK_CONTAINER (scroll), obj->priv->tree);
-	gtk_box_pack_start (GTK_BOX (obj), scroll, TRUE, TRUE, 0);
-}
-
 static void
 brasero_playlist_increase_activity_counter (BraseroPlaylist *playlist)
 {
@@ -409,149 +149,59 @@ brasero_playlist_decrease_activity_counter (BraseroPlaylist *playlist)
 }
 
 static void
-brasero_playlist_destroy (GtkObject *object)
+brasero_playlist_search_playlists_rhythmbox (BraseroPlaylist *playlist)
 {
-	BraseroPlaylist *playlist = BRASERO_PLAYLIST (object);
+/*	RBSource *source;
 
-#ifdef BUILD_SEARCH
-
-	if (playlist->priv->id) {
-		g_source_remove (playlist->priv->id);
-		playlist->priv->id = 0;
-	}
-
-	if (playlist->priv->client) {
-		g_object_unref (playlist->priv->client);
-		playlist->priv->client = NULL;
-	}
-
-	if (playlist->priv->query) {
-		g_object_unref (playlist->priv->query);
-		playlist->priv->query = NULL;
-	}
-
-#endif
-
-	/* NOTE: we must do it here since cancel could call brasero_playlist_end
-	 * itself calling decrease_activity_counter. In finalize the latter will
-	 * raise problems since the GdkWindow has been destroyed */
-	if (playlist->priv->parse_type) {
-		brasero_io_cancel_by_base (playlist->priv->parse_type);
-		g_free (playlist->priv->parse_type);
-		playlist->priv->parse_type = NULL;
-	}
-
-	if (GTK_OBJECT_CLASS (parent_class)->destroy)
-		GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	manager = rb_playlist_manager_new ();
+	lists = rb_playlist_manager_get_playlists (manager);
+*/
 }
 
 static void
-brasero_playlist_finalize (GObject *object)
+brasero_playlist_search (BraseroPlaylist *playlist)
 {
-	BraseroPlaylist *cobj;
+	const gchar* mimes [] = {"audio/x-ms-asx",
+		"audio/x-mpegurl",
+		"audio/x-scpls",
+		"audio/x-mp3-playlist",
+		NULL};
 
-	cobj = BRASERO_PLAYLIST (object);
-
-	g_free (cobj->priv);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	brasero_search_engine_new_query (playlist->priv->engine, NULL);
+	brasero_search_engine_set_query_mime (playlist->priv->engine, mimes);
+	brasero_search_engine_start_query (playlist->priv->engine);
+	brasero_playlist_increase_activity_counter (playlist);
 }
 
-#ifdef BUILD_SEARCH
-
 static gboolean
 brasero_playlist_try_again (BraseroPlaylist *playlist)
 {
-	playlist->priv->client = beagle_client_new (NULL);
-	if (!playlist->priv->client)
+	if (!brasero_search_engine_is_available (playlist->priv->engine))
 		return TRUE;
 
+	brasero_playlist_search (playlist);
+
 	playlist->priv->id = 0;
 	return FALSE;
 }
 
 static void
-brasero_playlist_start_beagle_search (BraseroPlaylist *playlist)
+brasero_playlist_start_search (BraseroPlaylist *playlist)
 {
-	playlist->priv->client = beagle_client_new (NULL);
-	if(playlist->priv->client) {
-		GError *error = NULL;
-		BeagleQueryPartOr *or_part;
-		BeagleQueryPartHuman *type;
-		BeagleQueryPartProperty *filetype;
+	if (!playlist->priv->engine)
+		return;
 
-		playlist->priv->query = beagle_query_new ();
-
-		g_signal_connect (G_OBJECT (playlist->priv->query), "hits-added",
-				  G_CALLBACK (brasero_playlist_beagle_hit_added_cb),
-				  playlist);
-		g_signal_connect (G_OBJECT (playlist->priv->query), "hits-subtracted",
-				  G_CALLBACK (brasero_playlist_beagle_hit_substracted_cb),
-				  playlist);
-		g_signal_connect (G_OBJECT (playlist->priv->query), "finished",
-				  G_CALLBACK (brasero_playlist_beagle_finished_cb),
-				  playlist);
-	
-		type = beagle_query_part_human_new ();
-		beagle_query_part_human_set_string (type, "type:File");
-		beagle_query_add_part (playlist->priv->query, BEAGLE_QUERY_PART (type));
-
-		or_part = beagle_query_part_or_new ();
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:MimeType");
-		beagle_query_part_property_set_value (filetype, "audio/x-ms-asx");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:MimeType");
-		beagle_query_part_property_set_value (filetype, "audio/x-mpegurl");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:MimeType");
-		beagle_query_part_property_set_value (filetype, "audio/x-scpls");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-
-		filetype = beagle_query_part_property_new ();
-		beagle_query_part_property_set_property_type (filetype, BEAGLE_PROPERTY_TYPE_KEYWORD);
-		beagle_query_part_property_set_key (filetype, "beagle:FileType");
-		beagle_query_part_property_set_value (filetype, "audio/x-mp3-playlist");
-		beagle_query_part_or_add_subpart (or_part, BEAGLE_QUERY_PART (filetype));
-
-		beagle_query_add_part (playlist->priv->query, BEAGLE_QUERY_PART (or_part));
-
-		brasero_playlist_increase_activity_counter (playlist);
-		beagle_client_send_request_async (playlist->priv->client,
-						  BEAGLE_REQUEST (playlist->priv->query),
-						  &error);
-		if (error) {
-			g_warning ("Could not connect to beagle : %s\n",
-				   error->message);
-			g_error_free (error);
-		}
-	}
-	else {
+	if (!brasero_search_engine_is_available (playlist->priv->engine)) {
 		/* we will retry in 10 seconds */
 		playlist->priv->id = g_timeout_add_seconds (10,
 							    (GSourceFunc) brasero_playlist_try_again,
 							    playlist);
+		return;
 	}
+
+	brasero_playlist_search (playlist);
 }
 
-#else
-
-static void
-brasero_playlist_start_beagle_search (BraseroPlaylist *playlist)
-{
-	
-}
-
-#endif /* BUILD_SEARCH */
-
 static gboolean
 brasero_playlist_expose_event_cb (GtkWidget *widget,
 				  gpointer event,
@@ -563,140 +213,13 @@ brasero_playlist_expose_event_cb (GtkWidget *widget,
 	 * is if they become apparent. That will avoid overhead */
 	if (!playlist->priv->searched) {
 		playlist->priv->searched = 1;
-		brasero_playlist_start_beagle_search (playlist);
+		brasero_playlist_start_search (playlist);
 		brasero_playlist_search_playlists_rhythmbox (playlist);
 	}
 
 	return FALSE;
 }
 
-GtkWidget *
-brasero_playlist_new ()
-{
-	BraseroPlaylist *obj;
-
-	obj = BRASERO_PLAYLIST (g_object_new (BRASERO_TYPE_PLAYLIST, NULL));
-
-	g_signal_connect (obj,
-			  "expose-event",
-			  G_CALLBACK (brasero_playlist_expose_event_cb),
-			  NULL);
-
-	return GTK_WIDGET (obj);
-}
-
-static gchar **
-brasero_playlist_get_selected_uris (BraseroURIContainer *container)
-{
-	BraseroPlaylist *playlist;
-
-	playlist = BRASERO_PLAYLIST (container);
-	return brasero_playlist_get_selected_uris_real (playlist);
-}
-
-static gchar *
-brasero_playlist_get_selected_uri (BraseroURIContainer *container)
-{
-	BraseroPlaylist *playlist;
-	gchar **uris = NULL;
-	gchar *uri;
-
-	playlist = BRASERO_PLAYLIST (container);
-	uris = brasero_playlist_get_selected_uris_real (playlist);
-
-	if (uris) {
-		uri = g_strdup (uris [0]);
-		g_strfreev (uris);
-		return uri;
-	}
-
-	return NULL;
-}
-
-static void
-brasero_playlist_add_cb (GtkButton *button, BraseroPlaylist *playlist)
-{
-	GtkWidget *dialog, *toplevel;
-	gchar *uri;
-	GSList *uris, *iter;
-	gint result;
-
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (playlist));
-	if (!GTK_WIDGET_TOPLEVEL (toplevel))
-		return;
-
-	dialog = gtk_file_chooser_dialog_new (_("Select Playlist"),
-					      GTK_WINDOW (toplevel),
-					      GTK_FILE_CHOOSER_ACTION_OPEN,
-					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-					      NULL);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
-					 GTK_RESPONSE_ACCEPT);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
-	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (dialog), TRUE);
-	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (dialog),
-						 g_get_home_dir ());
-
-	gtk_widget_show_all (dialog);
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	if (result == GTK_RESPONSE_CANCEL) {
-		gtk_widget_destroy (dialog);
-		return;
-	}
-
-	uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (dialog));
-	gtk_widget_destroy (dialog);
-
-	for (iter = uris; iter; iter = iter->next) {
-		uri = iter->data;
-		brasero_playlist_add_uri_playlist (playlist, uri, FALSE);
-		g_free (uri);
-	}
-	g_slist_free (uris);
-}
-
-static void
-brasero_playlist_remove_cb (GtkButton *button, BraseroPlaylist *playlist)
-{
-	GtkTreeSelection *selection;
-	GtkTreeModel *model;
-	GtkTreePath *path;
-	GtkTreeIter row;
-	GList *rows, *iter;
-	gboolean valid;
-
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (playlist->priv->tree));
-	rows = gtk_tree_selection_get_selected_rows (selection, &model);
-
-	if (rows == NULL)
-		return;
-
-	/* we just remove the lists removing particular songs would be a nonsense */
-	/* we must reverse the list otherwise the last paths wouldn't be valid */
-	for (iter = g_list_last (rows); iter; iter = iter->prev) {
-		path = iter->data;
-		valid = gtk_tree_model_get_iter (model, &row, path);
-		gtk_tree_path_free (path);
-
-		if (valid == FALSE)	/* if we remove the whole list it could happen that we try to remove twice a song */
-			continue;
-
-		if (gtk_tree_model_iter_has_child (model, &row)) {
-			GtkTreeIter child;
-
-			/* we remove the songs if it's a list */
-			gtk_tree_model_iter_children (model, &child, &row);
-			while (gtk_tree_store_remove (GTK_TREE_STORE (model), &child) == TRUE);
-			gtk_tree_store_remove (GTK_TREE_STORE (model),
-					       &row);
-		}
-	}
-
-	g_list_free (rows);
-}
-
 static gchar **
 brasero_playlist_get_selected_uris_real (BraseroPlaylist *playlist)
 {
@@ -760,6 +283,74 @@ brasero_playlist_get_selected_uris_real (BraseroPlaylist *playlist)
 	return uris;
 }
 
+static gchar **
+brasero_playlist_get_selected_uris (BraseroURIContainer *container)
+{
+	BraseroPlaylist *playlist;
+
+	playlist = BRASERO_PLAYLIST (container);
+	return brasero_playlist_get_selected_uris_real (playlist);
+}
+
+static gchar *
+brasero_playlist_get_selected_uri (BraseroURIContainer *container)
+{
+	BraseroPlaylist *playlist;
+	gchar **uris = NULL;
+	gchar *uri;
+
+	playlist = BRASERO_PLAYLIST (container);
+	uris = brasero_playlist_get_selected_uris_real (playlist);
+
+	if (uris) {
+		uri = g_strdup (uris [0]);
+		g_strfreev (uris);
+		return uri;
+	}
+
+	return NULL;
+}
+
+static void
+brasero_playlist_remove_cb (GtkButton *button, BraseroPlaylist *playlist)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreePath *path;
+	GtkTreeIter row;
+	GList *rows, *iter;
+	gboolean valid;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (playlist->priv->tree));
+	rows = gtk_tree_selection_get_selected_rows (selection, &model);
+
+	if (rows == NULL)
+		return;
+
+	/* we just remove the lists removing particular songs would be a nonsense */
+	/* we must reverse the list otherwise the last paths wouldn't be valid */
+	for (iter = g_list_last (rows); iter; iter = iter->prev) {
+		path = iter->data;
+		valid = gtk_tree_model_get_iter (model, &row, path);
+		gtk_tree_path_free (path);
+
+		if (valid == FALSE)	/* if we remove the whole list it could happen that we try to remove twice a song */
+			continue;
+
+		if (gtk_tree_model_iter_has_child (model, &row)) {
+			GtkTreeIter child;
+
+			/* we remove the songs if it's a list */
+			gtk_tree_model_iter_children (model, &child, &row);
+			while (gtk_tree_store_remove (GTK_TREE_STORE (model), &child) == TRUE);
+			gtk_tree_store_remove (GTK_TREE_STORE (model),
+					       &row);
+		}
+	}
+
+	g_list_free (rows);
+}
+
 static void
 brasero_playlist_drag_data_get_cb (GtkTreeView *tree,
 				   GdkDragContext *drag_context,
@@ -974,80 +565,106 @@ brasero_playlist_add_uri_playlist (BraseroPlaylist *playlist,
 }
 
 static void
-brasero_playlist_search_playlists_rhythmbox (BraseroPlaylist *playlist)
+brasero_playlist_add_cb (GtkButton *button, BraseroPlaylist *playlist)
 {
-/*	RBSource *source;
+	GtkWidget *dialog, *toplevel;
+	gchar *uri;
+	GSList *uris, *iter;
+	gint result;
 
-	manager = rb_playlist_manager_new ();
-	lists = rb_playlist_manager_get_playlists (manager);
-*/
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (playlist));
+	if (!GTK_WIDGET_TOPLEVEL (toplevel))
+		return;
+
+	dialog = gtk_file_chooser_dialog_new (_("Select Playlist"),
+					      GTK_WINDOW (toplevel),
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+					      NULL);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+					 GTK_RESPONSE_ACCEPT);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
+	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (dialog), TRUE);
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (dialog),
+						 g_get_home_dir ());
+
+	gtk_widget_show_all (dialog);
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if (result == GTK_RESPONSE_CANCEL) {
+		gtk_widget_destroy (dialog);
+		return;
+	}
+
+	uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (dialog));
+	gtk_widget_destroy (dialog);
+
+	for (iter = uris; iter; iter = iter->next) {
+		uri = iter->data;
+		brasero_playlist_add_uri_playlist (playlist, uri, FALSE);
+		g_free (uri);
+	}
+	g_slist_free (uris);
 }
 
-#ifdef BUILD_SEARCH
-
 static void
-brasero_playlist_beagle_hit_added_cb (BeagleQuery *query,
-				      BeagleHitsAddedResponse *response,
-				      BraseroPlaylist *playlist)
+brasero_playlist_search_hit_added_cb (BraseroSearchEngine *engine,
+                                      gpointer hit,
+                                      BraseroPlaylist *playlist)
 {
-	GSList *list, *iter;
-	BeagleHit *hit;
 	const char *uri;
 
-	list = beagle_hits_added_response_get_hits (response);
-	for (iter = list; iter; iter = iter->next) {
-		hit = iter->data;
-		uri = beagle_hit_get_uri (hit);
-		brasero_playlist_add_uri_playlist (playlist, uri, TRUE);
-	}
+	uri = brasero_search_engine_uri_from_hit (engine, hit);
+	brasero_playlist_add_uri_playlist (playlist, uri, TRUE);
 	brasero_playlist_decrease_activity_counter (playlist);
 }
 
 static void
-brasero_playlist_beagle_hit_substracted_cb (BeagleQuery *query,
-					    BeagleHitsSubtractedResponse *response,
-					    BraseroPlaylist *playlist)
+brasero_playlist_search_hit_substracted_cb (BraseroSearchEngine *engine,
+                                            gpointer hit,
+                                            BraseroPlaylist *playlist)
 {
-	GSList *list, *iter;
-	const char *uri;
-	char *row_uri;
-
 	GtkTreeModel *model;
 	GtkTreeIter row;
+	const gchar *uri;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (playlist->priv->tree));
+	uri = brasero_search_engine_uri_from_hit (engine, hit);
 
-	list = beagle_hits_subtracted_response_get_uris (response);
-	for (iter = list; iter; iter = iter->next) {
-		uri = iter->data;
+	if (!gtk_tree_model_get_iter_first (model, &row))
+		return;
 
-		if (!gtk_tree_model_get_iter_first (model, &row))
-			continue;
+	do {
+		char *row_uri;
 
-		do {
-			gtk_tree_model_get (model, &row,
-					    BRASERO_PLAYLIST_URI_COL, &row_uri,
-					    -1);
+		gtk_tree_model_get (model, &row,
+				    BRASERO_PLAYLIST_URI_COL, &row_uri,
+				    -1);
 
-			if (!strcmp (row_uri, uri)) {
-				gtk_tree_store_remove (GTK_TREE_STORE (model), &row);
-				g_free (row_uri);
-				break;
-			}
+		if (!strcmp (row_uri, uri)) {
+			gtk_tree_store_remove (GTK_TREE_STORE (model), &row);
 			g_free (row_uri);
-		} while (gtk_tree_model_iter_next (model, &row));
-	}
+			return;
+		}
+
+		g_free (row_uri);
+	} while (gtk_tree_model_iter_next (model, &row));
 }
 
 static void
-brasero_playlist_beagle_finished_cb (BeagleQuery *query,
-				     BeagleFinishedResponse *response,
-				     BraseroPlaylist *playlist)
+brasero_playlist_search_finished_cb (BraseroSearchEngine *engine,
+                                     BraseroPlaylist *playlist)
 {
 	brasero_playlist_decrease_activity_counter (playlist);
 }
 
-#endif /* BUILD_SEARCH */
+static void
+brasero_playlist_search_error_cb (BraseroSearchEngine *engine,
+                                  BraseroPlaylist *playlist)
+{
+
+}
 
 static void
 brasero_playlist_row_activated_cb (GtkTreeView *tree,
@@ -1065,4 +682,232 @@ brasero_playlist_selection_changed_cb (GtkTreeSelection *selection,
 	brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (playlist));
 }
 
-#endif /* BUILD_PLAYLIST */
+static void
+brasero_playlist_init (BraseroPlaylist *obj)
+{
+	GtkWidget *hbox, *scroll;
+	GtkTreeStore *store = NULL;
+	GtkCellRenderer *renderer;
+	GtkTreeViewColumn *column;
+
+	obj->priv = g_new0 (BraseroPlaylistPrivate, 1);
+	gtk_box_set_spacing (GTK_BOX (obj), BRASERO_PLAYLIST_SPACING);
+
+	hbox = gtk_hbox_new (FALSE, 8);
+	gtk_widget_show (hbox);
+
+	obj->priv->button_add = gtk_button_new_from_stock (GTK_STOCK_ADD);
+	gtk_widget_show (obj->priv->button_add);
+	gtk_box_pack_end (GTK_BOX (hbox),
+			  obj->priv->button_add,
+			  FALSE,
+			  FALSE,
+			  0);
+	g_signal_connect (G_OBJECT (obj->priv->button_add),
+			  "clicked",
+			  G_CALLBACK (brasero_playlist_add_cb),
+			  obj);
+
+	obj->priv->button_remove = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
+	gtk_widget_show (obj->priv->button_remove);
+	gtk_box_pack_end (GTK_BOX (hbox),
+			  obj->priv->button_remove,
+			  FALSE,
+			  FALSE,
+			  0);
+	g_signal_connect (G_OBJECT (obj->priv->button_remove),
+			  "clicked",
+			  G_CALLBACK (brasero_playlist_remove_cb),
+			  obj);
+
+	gtk_box_pack_end (GTK_BOX (obj), hbox, FALSE, FALSE, 0);
+
+	store = gtk_tree_store_new (BRASERO_PLAYLIST_NB_COL,
+				    G_TYPE_STRING,
+				    G_TYPE_STRING,
+				    G_TYPE_STRING,
+				    G_TYPE_STRING, 
+				    G_TYPE_STRING,
+				    G_TYPE_INT64);
+
+	obj->priv->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	egg_tree_multi_drag_add_drag_support (GTK_TREE_VIEW (obj->priv->tree));
+
+	gtk_tree_view_set_enable_tree_lines (GTK_TREE_VIEW (obj->priv->tree), TRUE);
+	gtk_tree_view_set_rubber_banding (GTK_TREE_VIEW (obj->priv->tree), TRUE);
+	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (obj->priv->tree), TRUE);
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (obj->priv->tree), TRUE);
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (obj->priv->tree), TRUE);
+	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (obj->priv->tree),
+					   BRASERO_PLAYLIST_DISPLAY_COL);
+
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes (_("Playlists"),
+							   renderer, "text",
+							   BRASERO_PLAYLIST_DISPLAY_COL,
+							   NULL);
+	gtk_tree_view_column_set_sort_column_id (column,
+						 BRASERO_PLAYLIST_DISPLAY_COL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
+				     column);
+	gtk_tree_view_column_set_expand (column, TRUE);
+
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes (_("Number of Songs"),
+							   renderer, "text",
+							   BRASERO_PLAYLIST_NB_SONGS_COL,
+							   NULL);
+	gtk_tree_view_column_set_sort_column_id (column,
+						 BRASERO_PLAYLIST_NB_SONGS_COL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
+				     column);
+
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes (_("Length"),
+							   renderer, "text",
+							   BRASERO_PLAYLIST_LEN_COL,
+							   NULL);
+	gtk_tree_view_column_set_sort_column_id (column,
+						 BRASERO_PLAYLIST_LEN_COL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
+				     column);
+
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes (_("Genre"), renderer,
+							   "text",
+							   BRASERO_PLAYLIST_GENRE_COL,
+							   NULL);
+	gtk_tree_view_column_set_sort_column_id (column,
+						 BRASERO_PLAYLIST_GENRE_COL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (obj->priv->tree),
+				     column);
+
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (obj->priv->tree),
+					 BRASERO_PLAYLIST_DISPLAY_COL);
+	gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (obj->priv->tree),
+						GDK_BUTTON1_MASK, ntables,
+						nb_ntables,
+						GDK_ACTION_COPY |
+						GDK_ACTION_MOVE);
+
+	g_signal_connect (G_OBJECT (obj->priv->tree), "drag_data_get",
+			  G_CALLBACK (brasero_playlist_drag_data_get_cb),
+			  obj);
+
+	g_signal_connect (G_OBJECT (obj->priv->tree), "row_activated",
+			  G_CALLBACK (brasero_playlist_row_activated_cb),
+			  obj);
+
+	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (obj->priv->tree))),
+			  "changed",
+			  G_CALLBACK (brasero_playlist_selection_changed_cb),
+			  obj);
+
+	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (obj->priv->tree)),
+				     GTK_SELECTION_MULTIPLE);
+
+	scroll = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
+					     GTK_SHADOW_IN);
+
+	gtk_container_add (GTK_CONTAINER (scroll), obj->priv->tree);
+	gtk_box_pack_start (GTK_BOX (obj), scroll, TRUE, TRUE, 0);
+
+	obj->priv->engine = brasero_search_engine_new_default ();
+	if (!obj->priv->engine)
+		return;
+
+	g_signal_connect (G_OBJECT (obj->priv->engine), "hit-added",
+			  G_CALLBACK (brasero_playlist_search_hit_added_cb),
+			  obj);
+	g_signal_connect (G_OBJECT (obj->priv->engine), "hit-removed",
+			  G_CALLBACK (brasero_playlist_search_hit_substracted_cb),
+			  obj);
+	g_signal_connect (G_OBJECT (obj->priv->engine), "search-finished",
+			  G_CALLBACK (brasero_playlist_search_finished_cb),
+			  obj);
+	g_signal_connect (G_OBJECT (obj->priv->engine), "search-error",
+			  G_CALLBACK (brasero_playlist_search_error_cb),
+			  obj);
+}
+
+static void
+brasero_playlist_destroy (GtkObject *object)
+{
+	BraseroPlaylist *playlist = BRASERO_PLAYLIST (object);
+
+	if (playlist->priv->id) {
+		g_source_remove (playlist->priv->id);
+		playlist->priv->id = 0;
+	}
+
+	if (playlist->priv->engine) {
+		g_object_unref (playlist->priv->engine);
+		playlist->priv->engine = NULL;
+	}
+
+	/* NOTE: we must do it here since cancel could call brasero_playlist_end
+	 * itself calling decrease_activity_counter. In finalize the latter will
+	 * raise problems since the GdkWindow has been destroyed */
+	if (playlist->priv->parse_type) {
+		brasero_io_cancel_by_base (playlist->priv->parse_type);
+		brasero_io_job_base_free (playlist->priv->parse_type);
+		playlist->priv->parse_type = NULL;
+	}
+
+	if (GTK_OBJECT_CLASS (brasero_playlist_parent_class)->destroy)
+		GTK_OBJECT_CLASS (brasero_playlist_parent_class)->destroy (object);
+}
+
+static void
+brasero_playlist_finalize (GObject *object)
+{
+	BraseroPlaylist *cobj;
+
+	cobj = BRASERO_PLAYLIST (object);
+
+	g_free (cobj->priv);
+
+	G_OBJECT_CLASS (brasero_playlist_parent_class)->finalize (object);
+}
+
+static void
+brasero_playlist_class_init (BraseroPlaylistClass *klass)
+{
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (klass);
+
+	object_class->finalize = brasero_playlist_finalize;
+	gtkobject_class->destroy = brasero_playlist_destroy;
+}
+
+static void
+brasero_playlist_iface_uri_container_init (BraseroURIContainerIFace *iface)
+{
+	iface->get_selected_uri = brasero_playlist_get_selected_uri;
+	iface->get_selected_uris = brasero_playlist_get_selected_uris;
+}
+
+static void
+brasero_playlist_iface_layout_object_init (BraseroLayoutObjectIFace *iface)
+{
+	iface->get_proportion = brasero_playlist_get_proportion;
+}
+
+GtkWidget *
+brasero_playlist_new ()
+{
+	BraseroPlaylist *obj;
+
+	obj = BRASERO_PLAYLIST (g_object_new (BRASERO_TYPE_PLAYLIST, NULL));
+
+	g_signal_connect (obj,
+			  "expose-event",
+			  G_CALLBACK (brasero_playlist_expose_event_cb),
+			  NULL);
+
+	return GTK_WIDGET (obj);
+}
