@@ -37,40 +37,39 @@
 #include <gio/gio.h>
 
 #include <gtk/gtk.h>
-
-#include <libxml/xmlerror.h>
-#include <libxml/xmlwriter.h>
-#include <libxml/parser.h>
-#include <libxml/xmlstring.h>
-#include <libxml/uri.h>
-
-#include <gconf/gconf-client.h>
+#include <gdk/gdkx.h>
 
 #include <gst/gst.h>
 
-#ifdef BUILD_PLAYLIST
-#include <totem-pl-parser.h>
-#endif
+#include "brasero-units.h"
 
 #include "brasero-misc.h"
 #include "brasero-jacket-edit.h"
+#include "brasero-pk.h"
 
 #include "brasero-tags.h"
 #include "brasero-session.h"
 
+#include "brasero-setting.h"
+
 #ifdef BUILD_PREVIEW
 #include "brasero-player.h"
 #endif
 
 #include "brasero-track-data.h"
 #include "brasero-session-cfg.h"
-#include "brasero-burn-options.h"
-#include "brasero-cover.h"
 
+/* These includes are not in the exported *.h files by 
+ * libbrasero-burn. */
 #include "brasero-medium-selection-priv.h"
 #include "brasero-session-helper.h"
-#include "brasero-session-cfg.h"
 #include "brasero-dest-selection.h"
+#include "brasero-cover.h"
+#include "brasero-status-dialog.h"
+#include "brasero-video-options.h"
+#include "brasero-drive-properties.h"
+#include "brasero-image-properties.h"
+#include "burn-plugin-manager.h"
 
 #include "brasero-project-type-chooser.h"
 #include "brasero-app.h"
@@ -85,11 +84,8 @@
 #include "brasero-file-chooser.h"
 #include "brasero-notify.h"
 #include "brasero-project-parse.h"
-#include "brasero-burn-options.h"
 #include "brasero-project-name.h"
 
-#include "brasero-image-properties.h"
-
 static void brasero_project_class_init (BraseroProjectClass *klass);
 static void brasero_project_init (BraseroProject *sp);
 static void brasero_project_iface_uri_container_init (BraseroURIContainerIFace *iface);
@@ -171,6 +167,8 @@ struct BraseroProjectPrivate {
 
 	BraseroURIContainer *current_source;
 
+	GCancellable *cancel;
+
 	GtkWidget *chooser;
 	gulong selected_id;
 	gulong activated_id;
@@ -189,7 +187,7 @@ struct BraseroProjectPrivate {
 static GtkActionEntry entries [] = {
 	{"Save", GTK_STOCK_SAVE, NULL, NULL,
 	 N_("Save current project"), G_CALLBACK (brasero_project_save_cb)},
-	{"SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), NULL,
+	{"SaveAs", GTK_STOCK_SAVE_AS, N_("Save _As…"), NULL,
 	 N_("Save current project to a different location"), G_CALLBACK (brasero_project_save_as_cb)},
 	{"Add", GTK_STOCK_ADD, N_("_Add Files"), NULL,
 	 N_("Add files to the project"), G_CALLBACK (brasero_project_add_uris_cb)},
@@ -198,7 +196,7 @@ static GtkActionEntry entries [] = {
 	/* Translators: "empty" is a verb here */
 	{"DeleteAll", GTK_STOCK_CLEAR, N_("E_mpty Project"), NULL,
 	 N_("Remove all files from the project"), G_CALLBACK (brasero_project_empty_cb)},
-	{"Burn", "media-optical-burn", N_("_Burn..."), NULL,
+	{"Burn", "media-optical-burn", N_("_Burn…"), NULL,
 	 N_("Burn the disc"), G_CALLBACK (brasero_project_burn_cb)},
 };
 
@@ -244,8 +242,6 @@ static GObjectClass *parent_class = NULL;
 
 #define BRASERO_PROJECT_SIZE_WIDGET_BORDER	1
 
-#define BRASERO_KEY_SHOW_PREVIEW		"/apps/brasero/display/viewer"
-
 #define BRASERO_PROJECT_VERSION "0.2"
 
 #define BRASERO_RESPONSE_ADD			1976
@@ -365,7 +361,7 @@ brasero_project_set_add_button_state (BraseroProject *project)
 	GtkWidget *toplevel;
 
 	sensitive = ((!project->priv->current_source || !project->priv->has_focus) &&
-		      !project->priv->oversized);
+		      !project->priv->oversized && !project->priv->chooser);
 
 	action = gtk_action_group_get_action (project->priv->project_group, "Add");
 	gtk_action_set_sensitive (action, sensitive);
@@ -661,7 +657,7 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 	gtk_container_add (GTK_CONTAINER (frame), event_box);
 
 	/* The alignment to set properly the position of the GtkTextView */
-	alignment = gtk_alignment_new (0.5, 0.3, 0.0, 0.0);
+	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 0.0);
 	gtk_container_set_border_width (GTK_CONTAINER (alignment), 10);
 	gtk_widget_show (alignment);
 	gtk_container_add (GTK_CONTAINER (event_box), alignment);
@@ -669,49 +665,16 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 	/* The TreeView for the message */
 	buffer = gtk_text_buffer_new (NULL);
 	gtk_text_buffer_create_tag (buffer, "Title",
-	                            "scale", 1.2,
-	                            "justification", GTK_JUSTIFY_LEFT,
-	                            "foreground", "grey50",
-	                            NULL);
-
-	gtk_text_buffer_create_tag (buffer, "TextBody",
-	                            "justification", GTK_JUSTIFY_LEFT,
+	                            "scale", 1.1,
+	                            "justification", GTK_JUSTIFY_CENTER,
 	                            "foreground", "grey50",
+	                            "wrap-mode", GTK_WRAP_WORD,
 	                            NULL);
 
 	gtk_text_buffer_get_start_iter (buffer, &iter);
-
-	/* Translators: this messages will appear as a list of possible
-	 * actions, like:
-	 *   To add/remove files you can:
-         *      * perform action one
-         *      * perform action two
-	 * The full message will be showed in the main area of an empty
-	 * project, suggesting users how to add and remove items to project.
-	 * You simply have to translate messages in the best form
-         * for a list of actions. */
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("To add files to this project you can:"), -1, "Title", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("click the \"Add\" button to show a selection dialog"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("select files in the selection pane and click the \"Add\" button"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("drag files in this area from the selection pane or from the file manager"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("double click on files in the selection pane"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("copy files (from file manager for example) and paste in this area"), -1, "TextBody", NULL);
+	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("To add files to this project click the \"Add\" button or drag files to this area"), -1, "Title", NULL);
 	gtk_text_buffer_insert (buffer, &iter, "\n\n\n", -1);
-
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("To remove files from this project you can:"), -1, "Title", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("click on the \"Remove\" button to remove selected items in this area"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("select items in this area, and choose \"Remove\" from context menu"), -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "\n\t* ", -1, "TextBody", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("select items in this area, and press \"Delete\" key"), -1, "TextBody", NULL);
+	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, _("To remove files select them then click on the \"Remove\" button or press \"Delete\" key"), -1, "Title", NULL);
 
 	textview = gtk_text_view_new_with_buffer (buffer);
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (textview), FALSE);
@@ -770,19 +733,23 @@ brasero_disc_get_use_info_notebook (BraseroProject *project)
 }
 
 /********************************** size ***************************************/
-
-gchar *
+static gchar *
 brasero_project_get_sectors_string (gint64 sectors,
-				    gboolean time_format)
+				    BraseroTrackType *type)
 {
 	gint64 size_bytes;
 
-	if (time_format) {
-		size_bytes = sectors * GST_SECOND / 75;
+	if (brasero_track_type_get_has_stream (type)) {
+		if (BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (type)))
+			/* This is an embarassing problem: this is an approximation
+			 * based on the fact that 2 hours = 4.3GiB */
+			size_bytes = sectors * 2048LL * 72000LL / 47LL;
+		else
+			size_bytes = sectors * GST_SECOND / 75LL;
 		return brasero_units_get_time_string (size_bytes, TRUE, FALSE);
 	}
 	else {
-		size_bytes = sectors * 2048;
+		size_bytes = sectors * 2048LL;
 		return g_format_size_for_display (size_bytes);
 	}
 }
@@ -811,10 +778,10 @@ brasero_project_update_project_size (BraseroProject *project)
 	session_type = brasero_track_type_new ();
 	brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (project->priv->session), session_type);
 
-	string = brasero_project_get_sectors_string (sectors, !brasero_track_type_get_has_data (session_type));
+	string = brasero_project_get_sectors_string (sectors, session_type);
 	brasero_track_type_free (session_type);
 
-	size_str = g_strdup_printf (_("Project estimated size: %s"), string);
+	size_str = g_strdup_printf (_("Estimated project size: %s"), string);
 	g_free (string);
 
 	gtk_statusbar_push (GTK_STATUSBAR (status), project->priv->status_ctx, size_str);
@@ -895,17 +862,17 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 			  BraseroProject *project)
 {
 	BraseroSessionError valid;
-	BraseroStatus *status;
 	GdkWindow *window;
 	GdkCursor *cursor;
 	GtkAction *action;
 
 	/* Update the cursor */
-	status = brasero_status_new ();
-	brasero_burn_session_get_status (BRASERO_BURN_SESSION (session), status);
-
 	window = gtk_widget_get_window (GTK_WIDGET (project));
 	if (window) {
+		BraseroStatus *status;
+
+		status = brasero_status_new ();
+		brasero_burn_session_get_status (BRASERO_BURN_SESSION (session), status);
 		if (brasero_status_get_result (status) == BRASERO_BURN_NOT_READY) {
 			cursor = gdk_cursor_new (GDK_WATCH);
 			gdk_window_set_cursor (window, cursor);
@@ -913,9 +880,9 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		}
 		else
 			gdk_window_set_cursor (window, NULL);
-	}
 
-	brasero_status_free (status);
+		g_object_unref (status);
+	}
 
 	valid = brasero_session_cfg_get_error (project->priv->session);
 
@@ -926,21 +893,40 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 
 	/* FIXME: update option button state as well */
 
+	/* NOTE: empty error is the first checked error; so if another errors comes up
+	 * that means that file selection is not empty */
+
 	/* Clean any message */
 	brasero_notify_message_remove (BRASERO_NOTIFY (project->priv->message),
 				       BRASERO_NOTIFY_CONTEXT_SIZE);
 
-	if (valid == BRASERO_SESSION_INSUFFICIENT_SPACE) {
+	if (valid == BRASERO_SESSION_EMPTY) {
+		project->priv->empty = TRUE;
+		project->priv->oversized = FALSE;
+	}
+	else if (valid == BRASERO_SESSION_INSUFFICIENT_SPACE) {
+		goffset min_disc_size;
+		goffset available_space;
+
 		project->priv->oversized = TRUE;
+		project->priv->empty = FALSE;
+
+		min_disc_size = brasero_session_span_get_max_space (BRASERO_SESSION_SPAN (session));
+
+		/* One rule should be that the maximum batch size should not exceed the disc size
+		 * FIXME! we could change it into a dialog telling the user what is the maximum
+		 * size required. */
+		available_space = brasero_burn_session_get_available_medium_space (BRASERO_BURN_SESSION (session));
 
 		/* Here there is an alternative: we may be able to span the data
 		 * across multiple media. So try that. */
-		if (brasero_session_span_possible (BRASERO_SESSION_SPAN (project->priv->session)) == BRASERO_BURN_RETRY) {
+		if (available_space > min_disc_size
+		&& brasero_session_span_possible (BRASERO_SESSION_SPAN (session)) == BRASERO_BURN_RETRY) {
 			GtkWidget *message;
 
 			message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 							      _("Would you like to burn the selection of files across several media?"),
-							      _("The size of the project is too large for the disc even with the overburn option."),
+							      _("The project is too large for the disc even with the overburn option."),
 							      -1,
 							      BRASERO_NOTIFY_CONTEXT_SIZE);
 			brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
@@ -957,25 +943,26 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		else
 			brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
 						    _("Please choose another CD or DVD or insert a new one."),
-						    _("The size of the project is too large for the disc even with the overburn option."),
+						    _("The project is too large for the disc even with the overburn option."),
 						    -1,
 						    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
 	else if (valid == BRASERO_SESSION_OVERBURN_NECESSARY) {
 		GtkWidget *message;
 
+		project->priv->empty = FALSE;
 		project->priv->oversized = TRUE;
 		message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-						      _("Would you like to burn beyond the disc reported capacity?"),
-						      _("The size of the project is too large for the disc and you must remove files from the project otherwise."
-							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognised and therefore need overburn option."
-							"\nNOTE: This option might cause failure."),
+						      _("Would you like to burn beyond the disc's reported capacity?"),
+						      _("The project is too large for the disc and you must remove files from it."
+							"\nYou may want to use this option if you're using 90 or 100 min CD-R(W) which cannot be properly recognized and therefore needs the overburn option."
+							"\nNote: This option might cause failure."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
 		brasero_notify_button_add (BRASERO_NOTIFY (project->priv->message),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Overburn"),
-					   _("Burn beyond the disc reported capacity"),
+					   _("Burn beyond the disc's reported capacity"),
 					   GTK_RESPONSE_OK);
 
 		g_signal_connect (message,
@@ -983,13 +970,19 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 				  G_CALLBACK (brasero_project_message_response_overburn_cb),
 				  project);
 	}
-	else if (valid == BRASERO_SESSION_EMPTY) {
-		project->priv->empty = TRUE;
-	}
 	else if (valid == BRASERO_SESSION_NO_OUTPUT) {
+		project->priv->empty = FALSE;
 		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-					    _("Please insert a recordable CD or DVD."),
-					    _("There is no recordable disc inserted."),
+					    _("Please insert a writable CD or DVD."),
+					    NULL,
+					    -1,
+					    BRASERO_NOTIFY_CONTEXT_SIZE);
+	}
+	else if (valid == BRASERO_SESSION_NOT_SUPPORTED) {
+		project->priv->empty = FALSE;
+		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
+					    _("Please replace the disc with a supported CD or DVD."),
+					    NULL,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
@@ -1000,19 +993,12 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 					    -1,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
 	}
-	else if (valid == BRASERO_SESSION_NOT_SUPPORTED) {
-		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-					    _("Please replace the disc with a supported CD or DVD."),
-					    _("It is not possible to write with the current set of plugins."),
-					    -1,
-					    BRASERO_NOTIFY_CONTEXT_SIZE);
-	}
 	else if (brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (project->priv->session))
 	     &&  brasero_medium_selection_get_media_num (BRASERO_MEDIUM_SELECTION (project->priv->selection)) == 1) {
 		/* The user may have forgotten to insert a disc so remind him of that if
 		 * there aren't any other possibility in the selection */
 		brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
-					    _("Please insert a recordable CD or DVD if you don't want to write to an image file."),
+					    _("Please insert a writable CD or DVD if you don't want to write to an image file."),
 					    NULL,
 					    10000,
 					    BRASERO_NOTIFY_CONTEXT_SIZE);
@@ -1077,7 +1063,7 @@ brasero_project_init (BraseroProject *obj)
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 
 	/* burn button set insensitive since there are no files in the selection */
-	obj->priv->burn = brasero_utils_make_button (_("_Burn..."),
+	obj->priv->burn = brasero_utils_make_button (_("_Burn…"),
 						     NULL,
 						     "media-optical-burn",
 						     GTK_ICON_SIZE_BUTTON);
@@ -1176,6 +1162,16 @@ brasero_project_finalize (GObject *object)
 	BraseroProject *cobj;
 	cobj = BRASERO_PROJECT(object);
 
+	if (cobj->priv->cancel) {
+		g_cancellable_cancel (cobj->priv->cancel);
+		cobj->priv->cancel = NULL;
+	}
+
+	if (cobj->priv->session) {
+		g_object_unref (cobj->priv->session);
+		cobj->priv->session = NULL;
+	}
+
 	if (cobj->priv->project)
 		g_free (cobj->priv->project);
 
@@ -1274,20 +1270,20 @@ brasero_project_check_status (BraseroProject *project)
         status = brasero_status_new ();
         brasero_burn_session_get_status (BRASERO_BURN_SESSION (project->priv->session), status);
         result = brasero_status_get_result (status);
-        brasero_status_free (status);
+        g_object_unref (status);
 
         if (result == BRASERO_BURN_ERR) {
                 /* At the moment the only error possible is an empty project */
-                if (BRASERO_IS_AUDIO_DISC (project->priv->current))
-                        brasero_project_no_song_dialog (project);
-                else
-                        brasero_project_no_file_dialog (project);
+		if (BRASERO_IS_AUDIO_DISC (project->priv->current))
+			brasero_project_no_song_dialog (project);
+		else
+			brasero_project_no_file_dialog (project);
 
-                return BRASERO_BURN_ERR;
-        }
+		return BRASERO_BURN_ERR;
+	}
 
-        if (result == BRASERO_BURN_OK)
-                return BRASERO_BURN_OK;
+	if (result == BRASERO_BURN_OK)
+		return BRASERO_BURN_OK;
 
         dialog = brasero_status_dialog_new (BRASERO_BURN_SESSION (project->priv->session),
                                                                   gtk_widget_get_toplevel (GTK_WIDGET (project)));
@@ -1299,6 +1295,124 @@ brasero_project_check_status (BraseroProject *project)
         return (response == GTK_RESPONSE_OK)? BRASERO_BURN_OK:BRASERO_BURN_CANCEL;
 }
 
+static BraseroBurnResult
+brasero_project_install_missing (BraseroPluginErrorType type,
+                                 const gchar *detail,
+                                 gpointer user_data)
+{
+	BraseroProject *project = BRASERO_PROJECT (user_data);
+	GCancellable *cancel;
+	BraseroPK *package;
+	GtkWidget *parent;
+	gboolean res;
+	int xid = 0;
+
+	/* Get the xid */
+	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
+	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (parent)->window));
+
+	package = brasero_pk_new ();
+	cancel = g_cancellable_new ();
+	project->priv->cancel = cancel;
+	switch (type) {
+		case BRASERO_PLUGIN_ERROR_MISSING_APP:
+			res = brasero_pk_install_missing_app (package, detail, xid, cancel);
+			break;
+
+		case BRASERO_PLUGIN_ERROR_MISSING_LIBRARY:
+			res = brasero_pk_install_missing_library (package, detail, xid, cancel);
+			break;
+
+		case BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN:
+			res = brasero_pk_install_gstreamer_plugin (package, detail, xid, cancel);
+			break;
+
+		default:
+			res = FALSE;
+			break;
+	}
+
+	if (package) {
+		g_object_unref (package);
+		package = NULL;
+	}
+
+	if (g_cancellable_is_cancelled (cancel)) {
+		g_object_unref (cancel);
+		return BRASERO_BURN_CANCEL;
+	}
+
+	project->priv->cancel = NULL;
+	g_object_unref (cancel);
+
+	if (!res)
+		return BRASERO_BURN_ERR;
+
+	return BRASERO_BURN_RETRY;
+}
+
+static BraseroBurnResult
+brasero_project_list_missing (BraseroPluginErrorType type,
+                              const gchar *detail,
+                              gpointer user_data)
+{
+	GString *string = user_data;
+
+	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing application */
+		g_string_append_printf (string, _("%s (application)"), detail);
+	}
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing library */
+		g_string_append_printf (string, _("%s (library)"), detail);
+	}
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_GSTREAMER_PLUGIN) {
+		g_string_append_c (string, '\n');
+		/* Translators: %s is the name of a missing Gstreamer plugin */
+		g_string_append_printf (string, _("%s (Gstreamer plugin)"), detail);
+	}
+
+	return BRASERO_BURN_OK;
+}
+
+static BraseroBurnResult
+brasero_project_check_plugins_not_ready (BraseroProject *project,
+                                         BraseroBurnSession *session)
+{
+	BraseroBurnResult result;
+	GtkWidget *parent;
+	GString *string;
+
+	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
+	gtk_widget_set_sensitive (parent, FALSE);
+
+	result = brasero_session_foreach_plugin_error (session,
+	                                               brasero_project_install_missing,
+	                                               project);
+	if (result == BRASERO_BURN_CANCEL)
+		return result;
+
+	gtk_widget_set_sensitive (parent, TRUE);
+
+	if (result == BRASERO_BURN_OK)
+		return result;
+
+	string = g_string_new (_("Please install the following manually and try again:"));
+	brasero_session_foreach_plugin_error (session,
+	                                      brasero_project_list_missing,
+	                                      string);
+
+	brasero_utils_message_dialog (parent,
+	                              _("All required applications and libraries are not installed."),
+	                              string->str,
+	                              GTK_MESSAGE_ERROR);
+	g_string_free (string, TRUE);
+
+	return BRASERO_BURN_ERR;
+}
+
 /******************************** burning **************************************/
 static void
 brasero_project_setup_session (BraseroProject *project,
@@ -1351,8 +1465,6 @@ brasero_project_drive_properties (BraseroProject *project)
 					      NULL);
 	g_free (header);
 
-	brasero_app_set_toplevel (brasero_app_get_default (), GTK_WINDOW (dialog));
-
 	button = brasero_utils_make_button (_("_Burn"),
 					    NULL,
 					    "media-optical-burn",
@@ -1384,8 +1496,10 @@ brasero_project_drive_properties (BraseroProject *project)
 	brasero_track_type_free (track_type);
 
 	medium_prop = brasero_drive_properties_new (project->priv->session);
-	gtk_widget_show (medium_prop);
 	gtk_box_pack_start (GTK_BOX (box), medium_prop, TRUE, TRUE, 0);
+	gtk_widget_show (medium_prop);
+
+	brasero_app_set_toplevel (brasero_app_get_default (), GTK_WINDOW (dialog));
 
 	/* launch the dialog */
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1397,6 +1511,7 @@ brasero_project_drive_properties (BraseroProject *project)
 static gboolean
 brasero_project_image_properties (BraseroProject *project)
 {
+	BraseroTrackType *track_type;
 	GtkResponseType answer;
 	GtkWidget *button;
 	GtkWidget *dialog;
@@ -1425,8 +1540,25 @@ brasero_project_image_properties (BraseroProject *project)
 
 	brasero_image_properties_set_session (BRASERO_IMAGE_PROPERTIES (dialog), project->priv->session);
 
+	track_type = brasero_track_type_new ();
+
+	brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (project->priv->session), track_type);
+	if (brasero_track_type_get_has_stream (track_type)
+	&& BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (track_type))) {
+		GtkWidget *box;
+		GtkWidget *options;
+
+		/* create video widget */
+		options = brasero_video_options_new (BRASERO_BURN_SESSION (project->priv->session));
+		gtk_widget_show (options);
+
+		box = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		gtk_box_pack_end (GTK_BOX (box), options, FALSE, TRUE, 0);
+	}
+
+	brasero_track_type_free (track_type);
+
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	gtk_widget_show_all (dialog);
 
 	/* launch the dialog */
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1441,6 +1573,14 @@ brasero_project_burn (BraseroProject *project)
 	gboolean res = FALSE;
 	BraseroDisc *current_disc;
 
+	/* Check that we are ready */
+	if (brasero_project_check_status (project) != BRASERO_BURN_OK)
+		return;
+
+	/* Check that we are not missing any plugin */
+	if (brasero_project_check_plugins_not_ready (project, BRASERO_BURN_SESSION (project->priv->session)) != BRASERO_BURN_OK)
+		return;
+
 	if (!brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (project->priv->session)))
 		res = brasero_project_drive_properties (project);
 	else
@@ -1481,8 +1621,7 @@ brasero_project_burn (BraseroProject *project)
 
 /******************************** cover ****************************************/
 void
-brasero_project_create_audio_cover (BraseroProject *project,
-				    BraseroJacketEdit *cover)
+brasero_project_create_audio_cover (BraseroProject *project)
 {
 	GtkWidget *window;
 
@@ -1562,12 +1701,18 @@ brasero_project_reset (BraseroProject *project)
 }
 
 static void
-brasero_project_new_session (BraseroProject *project)
+brasero_project_new_session (BraseroProject *project,
+                             BraseroSessionCfg *session)
 {
 	if (project->priv->session)
 		brasero_project_reset (project);
 
-	project->priv->session = brasero_session_cfg_new ();
+	if (session)
+		project->priv->session = g_object_ref (session);
+	else
+		project->priv->session = brasero_session_cfg_new ();
+
+	brasero_burn_session_set_strict_support (BRASERO_BURN_SESSION (project->priv->session), FALSE);
 
 	/* NOTE: "is-valid" is emitted whenever there is a change in the
 	 * contents of the session. So no need to connect to track-added, ... */
@@ -1603,7 +1748,8 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 		project->priv->current = BRASERO_DISC (project->priv->audio);
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (project->priv->discs), 0);
 		brasero_medium_selection_show_media_type (BRASERO_MEDIUM_SELECTION (project->priv->selection),
-							  BRASERO_MEDIA_TYPE_WRITABLE);
+							  BRASERO_MEDIA_TYPE_WRITABLE|
+		                                          BRASERO_MEDIA_TYPE_CD);
 	}
 	else if (type == BRASERO_PROJECT_TYPE_DATA) {
 		project->priv->current = BRASERO_DISC (project->priv->data);
@@ -1651,7 +1797,7 @@ brasero_project_switch (BraseroProject *project, BraseroProjectType type)
 void
 brasero_project_set_audio (BraseroProject *project, GSList *uris)
 {
-	brasero_project_new_session (project);
+	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_AUDIO);
 
 	for (; uris; uris = uris->next) {
@@ -1666,7 +1812,7 @@ void
 brasero_project_set_data (BraseroProject *project,
 			  GSList *uris)
 {
-	brasero_project_new_session (project);
+	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_DATA);
 
 	for (; uris; uris = uris->next) {
@@ -1680,7 +1826,7 @@ brasero_project_set_data (BraseroProject *project,
 void
 brasero_project_set_video (BraseroProject *project, GSList *uris)
 {
-	brasero_project_new_session (project);
+	brasero_project_new_session (project, NULL);
 	brasero_project_switch (project, BRASERO_PROJECT_TYPE_VIDEO);
 
 	for (; uris; uris = uris->next) {
@@ -1855,10 +2001,24 @@ static void
 brasero_project_file_chooser_activated_cb (GtkWidget *chooser,
 					   BraseroProject *project)
 {
+	gboolean sensitive;
+	GtkAction *action;
 	GSList *uris;
 	GSList *iter;
 
+	if (!project->priv->chooser)
+		return;
+
+	project->priv->chooser = NULL;
 	uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (chooser));
+	gtk_widget_destroy (GTK_WIDGET (chooser));
+
+	sensitive = ((!project->priv->current_source || !project->priv->has_focus) &&
+		      !project->priv->oversized);
+
+	action = gtk_action_group_get_action (project->priv->project_group, "Add");
+	gtk_action_set_sensitive (action, sensitive);
+
 	for (iter = uris; iter; iter = iter->next) {
 		gchar *uri;
 
@@ -1867,9 +2027,6 @@ brasero_project_file_chooser_activated_cb (GtkWidget *chooser,
 	}
 	g_slist_foreach (uris, (GFunc) g_free, NULL);
 	g_slist_free (uris);
-
-	gtk_widget_destroy (GTK_WIDGET (project->priv->chooser));
-	project->priv->chooser = NULL;
 }
 
 static void
@@ -1877,16 +2034,30 @@ brasero_project_file_chooser_response_cb (GtkWidget *chooser,
 					  GtkResponseType response,
 					  BraseroProject *project)
 {
+	gboolean sensitive;
+	GtkAction *action;
 	GSList *uris;
 	GSList *iter;
 
+	if (!project->priv->chooser)
+		return;
+
+	sensitive = ((!project->priv->current_source || !project->priv->has_focus) &&
+		      !project->priv->oversized);
+
+	action = gtk_action_group_get_action (project->priv->project_group, "Add");
+	gtk_action_set_sensitive (action, sensitive);
+
 	if (response != BRASERO_RESPONSE_ADD) {
 		gtk_widget_destroy (chooser);
 		project->priv->chooser = NULL;
 		return;
 	}
 
+	project->priv->chooser = NULL;
 	uris = gtk_file_chooser_get_uris (GTK_FILE_CHOOSER (chooser));
+	gtk_widget_destroy (GTK_WIDGET (chooser));
+
 	for (iter = uris; iter; iter = iter->next) {
 		gchar *uri;
 
@@ -1895,9 +2066,6 @@ brasero_project_file_chooser_response_cb (GtkWidget *chooser,
 	}
 	g_slist_foreach (uris, (GFunc) g_free, NULL);
 	g_slist_free (uris);
-
-	gtk_widget_destroy (GTK_WIDGET (project->priv->chooser));
-	project->priv->chooser = NULL;
 }
 
 static void
@@ -1932,6 +2100,11 @@ brasero_project_add_uris_cb (GtkAction *action,
 		return;
 	}
 
+	/* Set the Add button grey as we don't want
+	 * the user to be able to click again until the
+	 * dialog has been closed */
+	gtk_action_set_sensitive (action, FALSE);
+
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (project));
 	project->priv->chooser = gtk_file_chooser_dialog_new (_("Select Files"),
 							      GTK_WINDOW (toplevel),
@@ -1939,7 +2112,7 @@ brasero_project_add_uris_cb (GtkAction *action,
 							      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 							      NULL);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (project->priv->chooser), TRUE);
-	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (project->priv->chooser), TRUE);
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (project->priv->chooser), FALSE);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (project->priv->chooser), g_get_home_dir ());
 	brasero_file_chooser_customize (project->priv->chooser, NULL);
 	gtk_widget_show (project->priv->chooser);
@@ -1990,6 +2163,9 @@ brasero_project_add_uris_cb (GtkAction *action,
 	gtk_file_filter_add_mime_type (filter, "application/x-flash-video");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (project->priv->chooser), filter);
 
+	if (BRASERO_IS_VIDEO_DISC (project->priv->current))
+		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (project->priv->chooser), filter);
+
 	filter = gtk_file_filter_new ();
 	/* Translators: this is an image, a picture, not a "Disc Image" */
 	gtk_file_filter_set_name (filter, C_("picture", "Image files"));
@@ -1998,15 +2174,14 @@ brasero_project_add_uris_cb (GtkAction *action,
 
 #ifdef BUILD_PREVIEW
 
-	GConfClient *client;
 	GtkWidget *player;
-	gboolean res;
+	gpointer value;
 
-	client = gconf_client_get_default ();
-	res = gconf_client_get_bool (client, BRASERO_KEY_SHOW_PREVIEW, NULL);
-	g_object_unref (client);
+	brasero_setting_get_value (brasero_setting_get_default (),
+	                           BRASERO_SETTING_SHOW_PREVIEW,
+	                           &value);
 
-	if (!res)
+	if (!GPOINTER_TO_INT (value))
 		return;
 
 	/* if preview is activated add it */
@@ -2185,13 +2360,13 @@ brasero_project_set_uri (BraseroProject *project,
     	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
 	if (type == BRASERO_PROJECT_TYPE_DATA)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Data Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Data Disc)"), name);
 	else if (type == BRASERO_PROJECT_TYPE_AUDIO)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Audio Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Audio Disc)"), name);
 	else if (type == BRASERO_PROJECT_TYPE_VIDEO)
 		/* Translators: %s is the name of the project */
-		title = g_strdup_printf (_("Brasero - %s (Video Disc)"), name);
+		title = g_strdup_printf (_("Brasero — %s (Video Disc)"), name);
 	else
 		title = NULL;
  
@@ -2234,30 +2409,15 @@ brasero_project_get_session_type (BraseroProject *project)
 
 /******************************* Projects **************************************/
 BraseroProjectType
-brasero_project_open_project_real (BraseroProject *project,
-				   const gchar *uri,	/* escaped */
-				   gboolean playlist,
-				   gboolean warn_user)
+brasero_project_open_session (BraseroProject *project,
+                              BraseroSessionCfg *session)
 {
 	GValue *value;
 	BraseroProjectType type;
 
-	brasero_project_new_session (project);
+	brasero_project_new_session (project, session);
 
-#ifdef BUILD_PLAYLIST
-
-	if (playlist) {
-		if (!brasero_project_open_audio_playlist_project (uri, BRASERO_BURN_SESSION (project->priv->session), warn_user))
-			return BRASERO_PROJECT_TYPE_INVALID;
-	}
-	else
-
-#endif
-	
-	if (!brasero_project_open_project_xml (uri, BRASERO_BURN_SESSION (project->priv->session), warn_user))
-		return BRASERO_PROJECT_TYPE_INVALID;
-
-        type = brasero_project_get_session_type (project);
+	type = brasero_project_get_session_type (project);
         if (type == BRASERO_PROJECT_TYPE_INVALID)
                 return type;
 
@@ -2290,27 +2450,6 @@ brasero_project_open_project_real (BraseroProject *project,
 	return type;
 }
 
-BraseroProjectType
-brasero_project_open_project (BraseroProject *project,
-			      const gchar *uri,
-			      gboolean playlist)	/* escaped */
-{
-	BraseroProjectType type;
-
-	type = brasero_project_open_project_real (project, uri, playlist, TRUE);
-	if (type != BRASERO_PROJECT_TYPE_INVALID && uri)
-		brasero_project_set_uri (project, uri, type);
-
-	return type;
-}
-
-BraseroProjectType
-brasero_project_load_session (BraseroProject *project,
-			      const gchar *uri)
-{
-	return brasero_project_open_project_real (project, uri, FALSE, FALSE);
-}
-
 /******************************** save project *********************************/
 static void
 brasero_project_not_saved_dialog (BraseroProject *project)
@@ -2320,7 +2459,7 @@ brasero_project_not_saved_dialog (BraseroProject *project)
 	error = xmlGetLastError ();
 	brasero_app_alert (brasero_app_get_default (),
 			   _("Your project has not been saved."),
-			   error? error->message:_("An unknown error occured"),
+			   error? error->message:_("An unknown error occurred"),
 			   GTK_MESSAGE_ERROR);
 	xmlResetLastError ();
 }
@@ -2394,6 +2533,7 @@ brasero_project_save_project_real (BraseroProject *project,
 		return FALSE;
 	}
 
+	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
         type = brasero_project_get_session_type (project);
 
 	if (save_type == BRASERO_PROJECT_SAVE_XML
@@ -2460,15 +2600,15 @@ brasero_project_save_project_ask_for_path (BraseroProject *project,
 		combo = gtk_combo_box_new_text ();
 		gtk_widget_show (combo);
 
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as Brasero audio project"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a Brasero audio project"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a plain text list"));
 
 #ifdef BUILD_PLAYLIST
 
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a PLS playlist"));
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an M3U playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as a XSPF playlist"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an IRIVER playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an XSPF playlist"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Save project as an iriver playlist"));
 
 #endif
 
@@ -2627,10 +2767,33 @@ brasero_project_save_session (BraseroProject *project,
 		return FALSE;
 	}
 
-	/* NOTE: is this right? because brasero could not shut itself
-	 * down if an error occurs. */
-	if (!brasero_project_save_project_xml (BRASERO_BURN_SESSION (project->priv->session), uri))
-		return TRUE;
+	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
+	if (!brasero_project_save_project_xml (BRASERO_BURN_SESSION (project->priv->session), uri)) {
+		GtkResponseType response;
+		GtkWidget *dialog;
+
+		/* If the automatic saving failed, let the user decide */
+		dialog = brasero_app_dialog (brasero_app_get_default (),
+					      _("Your project has not been saved."),
+					     GTK_BUTTONS_NONE,
+					     GTK_MESSAGE_WARNING);
+
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("If you don't save, changes will be permanently lost."));
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+		                        _("Cl_ose Without Saving"), GTK_RESPONSE_NO,
+		                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                        NULL);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+
+		if (saved_uri)
+			*saved_uri = NULL;
+
+		return (response == GTK_RESPONSE_CANCEL);
+	}
 
 	if (saved_uri)
 		*saved_uri = g_strdup (uri);
